/*****************************************************************************/
/*                                                                           */
/*    COPYRIGHT : 5765 - 196                                                 */
/*                5765 - 476                                                 */
/*                5765 - 477                                                 */
/*    @(#)(C) Copyright IBM Corp. 1993, 1995, 1996                           */
/*                                                                           */
/*    ALL RIGHTS RESERVED                                                    */
/*    LICENSED MATERIALS - PROPERTY OF IBM                                   */
/*                                                                           */
/* Product:         NetView Distribution Manager/6000                        */
/*                                                                           */
/* Module:          fndcxcm.c                                                */
/*                                                                           */
/* Component:       D & CC Agent User-Exit Routines                          */
/*                                                                           */
/* Description:     This module contains the DACA User-Exit to handle the    */
/*                  CM_STATUS and the secure keys in change files.           */
/*                                                                           */
/*                  - cx_vercm             verify cm status                  */
/*                  - cx_set_secure_key    set secure key in change file     */
/*                  - cx_check_secure_key  check the secure key in change    */
/*                                         file                              */
/*                  - cx_check_crcs        check crcs related to the object  */
/*                                         in change file                    */
/*                                                                           */
/*                                                                           */
/* Prerequisites:   fndhdr.h                                                 */
/*                  fndshrr.h                                                */
/*                  fndcx.h                                                  */
/*                  swvpd.h                                                  */
/*                  string.h                                                 */
/*                  errno.h                                                  */
/*                                                                           */
/*                                                                           */
/*                                                                           */
/*****************************************************************************/
#ifdef _XOPEN_SOURCE
#undef _XOPEN_SOURCE
#endif


#include <fndhdr.h>
#include <fndshrr.h>
#include <fndcx.h>

#include <string.h>
#include <stdio.h>
#include <errno.h>
#include <stdlib.h>

/*
define DVA_TEST_USER_EXITS
*/

#ifdef DVA_TEST_USER_EXITS
#define FNDUEX_TRC "fnduex_trc"
#endif


DC_SHORT cx_vercm(DC_CHAR *cf_type,
                  DC_EXT_PRODUCT *product,
                  DC_EXT_FILESET *fileset,
                  DC_CHAR        *mask)
/*****************************************************************************/
/*                                                                           */
/* Description:                                                              */
/*  This function is called by the Netview DM/6000 agent to write into the   */
/*  fileset state field (see DVA_EXT_FILESET structure) the real status      */
/*  of the fileset in the target according to the relationship between       */
/*  the status of the fileset in a non-nvdm database and the change file     */
/*  CM status.                                                               */
/*                                                                           */
/* Parameters:                                                               */
/*     cf_type:  type of the change file                                     */
/*     product:  pointer to the product fields                               */
/*     fileset:  pointer to the fileset fields                               */
/*     mask   :  pointer to the mask used by agent to compare the            */
/*               fileset status with the change file status                  */
/*                                                                           */
/* Returns:     0                                                            */
/*              4  DB error                                                  */
/*             12  exit routine error                                        */
/*****************************************************************************/
{

  DC_SHORT rc=0;
  return rc;
}

DC_VOID cx_set_secure_key( DC_ULONG  *crc_vector,
                           DC_USHORT  number_of_crcs,
                           DC_VOID   *secure_key,
                           DC_USHORT  secure_key_len)
/*****************************************************************************/
/*                                                                           */
/* Description:                                                              */
/*  This function is called by the Netview DM/6000 user interface in order   */
/*  to calculate, using a user-defined algorithm, the secure key associated  */
/*  with a Change File.                                                      */
/*                                                                           */
/*                                                                           */
/* Parameters:                                                               */
/*     crc_vector:     pointer to the array containing the CRCs associated   */
/*                     with all the objects in the Change File.              */
/*                     (the CRC is 0 for the directories and for objects     */
/*                     to be deleted).                                       */
/*     number_of_crcs: number of elements in the vector.                     */
/*     secure_key:     buffer containing the calculated secure key to be     */
/*                     verified at installation time (to be returned).       */
/*                     Netview DM/6000 assumes that if all the bytes         */
/*                     are equal to '\0', the buffer is empty and no secure  */
/*                     key will be associated with the change file.          */
/*                     This is the default.                                  */
/*                                                                           */
/*     secure_key_len: length of the secure key (equal to 32 bytes).         */
/*                                                                           */
/* Returns:     None                                                         */
/*****************************************************************************/
{
#ifdef DVA_TEST_USER_EXITS
  /***************************************************************************/
  /*                                                                         */
  /* Sample cx_set_secure_key user exit                                      */
  /*                                                                         */
  /***************************************************************************/

  DC_CHAR    * trcfile_path ;
  FILE       * trcfile ;
  DC_USHORT  count = 0;
  DC_ULONG   secure_sum = 0L;

  /***************************************************************************/
  /* Look for fnduex_trc environment variable                                */
  /***************************************************************************/
  trcfile_path = getenv(FNDUEX_TRC) ;

  /***************************************************************************/
  /* if fnduex_trc is not null, it is considered as the full path name       */
  /* of a trace file                                                         */
  /***************************************************************************/
  if ( (trcfile_path != NULL) && (*trcfile_path != '\0') )
  {
    /*************************************************************************/
    /* Open the trace file in append mode                                    */
    /*************************************************************************/
    trcfile = fopen(trcfile_path, "a" ) ;
    if (trcfile != NULL)
    {
      /***********************************************************************/
      /* Append some data                                                    */
      /***********************************************************************/
      fprintf(trcfile, "\n\nstart list of crcs:\n") ;
      for (count=0; count < number_of_crcs; count++)
      {
        fprintf(trcfile, "%u\n", *(crc_vector+count)) ;
        /*********************************************************************/
        /* simple algorithm to calculate the secure key                      */
        /*********************************************************************/
        secure_sum = secure_sum + ((*(crc_vector+count))>>1) >> 1;
      }
      memcpy(secure_key, &secure_sum, sizeof(secure_sum));
      fprintf(trcfile, "secure key = %u\n", secure_sum) ;

      fprintf(trcfile, "\nend list of crcs.\n") ;
    }
    fclose(trcfile) ;
  }



#endif
  return;
}

DC_VOID cx_check_secure_key( DC_VOID   *secure_key,
                             DC_USHORT  secure_key_len,
                             DC_USHORT *action)
/*****************************************************************************/
/*                                                                           */
/* Description:                                                              */
/*  This function is called by the Netview DM/6000 agent to allow at install */
/*  time checks on the secure key contained in the change file and set by    */
/*  the cx_set_secure_key at preparation time.                               */
/*                                                                           */
/*                                                                           */
/* Parameters:                                                               */
/*     secure_key:     buffer containing the secure key to be verified.      */
/*     secure_key_len: length of the secure key (equal to 32 bytes).         */
/*     action:   Allowed values are:                                         */
/*                 - CM_INSTALLABLE                                          */
/*                         This is the default. If this value is returned,   */
/*                         the agent continue the installation.              */
/*                 - CM_NO_INSTALLABLE                                       */
/*                         If this value is returned, the agent ends the     */
/*                         installation of the change file reporting a       */
/*                         failure.                                          */
/*                                                                           */
/* Returns:     None                                                         */
/*****************************************************************************/
{
  DC_USHORT counter;

#ifdef DVA_TEST_USER_EXITS
  *action = CM_NO_INSTALLABLE;
  for (counter = 0; counter < secure_key_len; counter++)
  {
    if (((DC_CHAR *)secure_key)[counter] != '\0')
    {
      *action = CM_INSTALLABLE;
      break;
    }
  }
#else
  *action = CM_INSTALLABLE;
#endif
  return;
}


DC_VOID cx_check_crcs( DC_ULONG  *crc_vector,
                       DC_USHORT  number_of_crcs,
                       DC_VOID   *secure_key,
                       DC_USHORT  secure_key_len,
                       DC_USHORT *action)
/*****************************************************************************/
/*                                                                           */
/* Description:                                                              */
/*  This function is called at install time by the Netview DM/6000 agent to  */
/*  recalculate, using a user-defined algorithm, the secure key based on the */
/*  provided list of crc, and compare it with the secure key calculated at   */
/*  preparation time.                                                        */
/*                                                                           */
/*                                                                           */
/* Parameters:                                                               */
/*     crc_vector:     pointer to the array containing the CRCs associated   */
/*                     with all the objects in the Change File.              */
/*                     (the CRC is 0 for the directories and for objects     */
/*                     to be deleted).                                       */
/*     number_of_crcs: number of elements in the vector.                     */
/*     secure_key:     buffer containing the calculated secure key to be     */
/*                     verified at installation time                         */
/*     secure_key_len: length of the secure key (equal to 32 bytes).         */
/*     action:   Allowed values are:                                         */
/*                 - CM_INSTALLABLE                                          */
/*                         This is the default. Continue the installation    */
/*                 - CM_NO_INSTALLABLE                                       */
/*                         If this value is returned, it means that the      */
/*                         comparison between the secure key calculated at   */
/*                         preparation time, and the secure key calculated   */
/*                         at install time was not successful.               */
/*                         In this case NetView DM/6000 agent ends the       */
/*                         installation reporting a failure.                 */
/*                                                                           */
/* Returns:     None                                                         */
/*****************************************************************************/
{
#ifdef DVA_TEST_USER_EXITS
  /***************************************************************************/
  /*                                                                         */
  /* Sample cx_check_crcs user exit                                          */
  /*                                                                         */
  /***************************************************************************/

  DC_CHAR    * trcfile_path ;
  FILE       * trcfile ;
  DC_USHORT  count = 0;
  DC_ULONG   secure_sum = 0L;

  /***************************************************************************/
  /* Look for fnduex_trc environment variable                                */
  /***************************************************************************/
  trcfile_path = getenv(FNDUEX_TRC) ;

  /***************************************************************************/
  /* if fnduex_trc is not null, it is considered as the full path name       */
  /* of a trace file                                                         */
  /***************************************************************************/
  if ( (trcfile_path != NULL) && (*trcfile_path != '\0') )
  {
    /*************************************************************************/
    /* Open the trace file in append mode                                    */
    /*************************************************************************/
    trcfile = fopen(trcfile_path, "a" ) ;
    if (trcfile != NULL)
    {
      /***********************************************************************/
      /* Append some data                                                    */
      /***********************************************************************/
      fprintf(trcfile, "\n\nstart list of crcs at install time:\n") ;
      for (count=0; count < number_of_crcs; count++)
      {
        fprintf(trcfile, "%u\n", *(crc_vector+count)) ;
        /*********************************************************************/
        /* simple algorithm to calculate the secure key                      */
        /*********************************************************************/
        secure_sum = secure_sum + ((*(crc_vector+count))>>1) >> 1;
      }
      fprintf(trcfile, "secure key = %u\n", secure_sum) ;
      if (memcmp(secure_key, &secure_sum, sizeof(secure_sum)) != 0)
      {
        *action = CM_NO_INSTALLABLE;
        fprintf(trcfile, "\nend list of crcs at install time:\n") ;
        fclose(trcfile) ;
        return;
      }

      fprintf(trcfile, "\nend list of crcs at install time.\n") ;
    }
    fclose(trcfile) ;
  }
#endif

  *action = CM_INSTALLABLE;
  return;
}

/* fndcxcm.c */
