/*****************************************************************************/
/*                                                                           */
/*    COPYRIGHT : 5765 - 196                                                 */
/*                5765 - 476                                                 */
/*                5765 - 477                                                 */
/*    @(#)(C) Copyright IBM Corp. 1993, 1995, 1996                           */
/*                                                                           */
/*    ALL RIGHTS RESERVED                                                    */
/*    LICENSED MATERIALS - PROPERTY OF IBM                                   */
/*                                                                           */
/* Product:         NetView Distribution Manager/6000                        */
/*                                                                           */
/* Module:          fndcxmo.c                                                */
/*                                                                           */
/* Component:       Daca User-Exit Routines                                  */
/*                                                                           */
/* Description:     This module contains the DACA User-Exit to mount and     */
/*                  unmount a File System at client site.                    */
/*                  The following routines are provided:                     */
/*                                                                           */
/*                   - cx_mount_fs     to mount a File System                */
/*                   - cx_unmount_fs   to unmount a File System              */
/*                                                                           */
/*                                                                           */
/* Prerequisites:   fndhdr.h                                                 */
/*                  fndshrr.h                                                */
/*                  fndcx.h                                                  */
/*                                                                           */
/* Notice:          User is suggested to redirect the output                 */
/*                  of the OS commands issued in this user-exit              */
/*                  in a proper location                                     */
/*                                                                           */
/*                                                                           */
/*****************************************************************************/

#include <string.h>                     /* C header                          */
#include <signal.h>                     /* C header                          */
#include <stdio.h>                      /* C header                          */
#include <fcntl.h>                      /* C header                          */

#include <fndshrr.h>
#include <fndhdr.h>
#include <fndcx.h>

#define FILE_SYSTEM               " \\\\"
#define REMOTE_DIRECTORY          "\\"
#define MOUNT                     "net use "
#define UNMOUNT                   "net use "
#define DELETE                    " /DELETE"
#define DO_NOT_UNMOUNT            1

#ifdef DVW32S_ENV
#define CO_DIR_SEP_CHR   '\\'   /*  Directory separating character      $Z11 M*/
#endif

short check_drive(char * remote_d);

DC_USHORT cx_mount_fs   ( REMOTE_DIR    *remote_dir,
                          DC_VOID      **user_data,
                          DC_USHORT prot)
/*****************************************************************************/
/*                                                                           */
/* Description: This routine is called by the agent to mount a list of File  */
/*              Systems.                                                     */
/*              It is called before executing the request.                   */
/*                                                                           */
/* Parameters:                                                               */
/*              *remote_dir    : remote directory to be mounted              */
/*              **user_data    : user exit data. The same is passed          */
/*                               to the cx_unmount_fs user exit              */
/*              prot           : transport protocol (not used)               */
/*                                                                           */
/* Returns:     0   : File system successfully mounted.                      */
/*                    An informational message is logged.                    */
/*              4   : File System already mounted.                           */
/*                    An informational message is logged.                    */
/*              8   : An error was encountered mounting the File System.     */
/*                    An error message is logged and the Operating System    */
/*                    error_code is returned in the output parameter errcode.*/
/*                                                                           */
/*****************************************************************************/
{
 DC_CHAR       mount_cmd[256];
 DC_USHORT     error;
 DC_USHORT     rc;
 DC_USHORT    *udata;
 rc = DC_OK;

/*****************************************************************************/
/* Set the parameter to pass to system call: this parameter contains the     */
/* command to be issued, in this case mount (mknfsmnt)                       */
/*****************************************************************************/
 udata =  malloc(sizeof(DC_USHORT));
 *udata = 0;

 memset(mount_cmd, '\0', sizeof(mount_cmd));

/*****************************************************************************/
/* Build the command to mount the File System                                */
/*****************************************************************************/

 strcpy(mount_cmd, MOUNT);
 strcat(mount_cmd, remote_dir->mounted_fs);

 strcat(mount_cmd, FILE_SYSTEM);
 strcat(mount_cmd, remote_dir->server_name);

 strcat(mount_cmd, REMOTE_DIRECTORY);
 strcat(mount_cmd, remote_dir->exported_dir);

 strcat(mount_cmd, " ");
 strcat(mount_cmd, remote_dir->mount_options);

 strcat(mount_cmd, " ");
 strcat(mount_cmd, "< NUL");

 error = 0;
/*****************************************************************************/
/* Issue the command                                                         */
/*****************************************************************************/

#ifdef DVW32S_ENV
 error = exec_pgm(mount_cmd);
 if (error <  32)
 {
   *udata = DO_NOT_UNMOUNT;
   *user_data = (DC_VOID *)udata;
   return(MNT_ERROR);
 }

#else
 error = system(mount_cmd);
 if (error != 0)
 {
    *udata = DO_NOT_UNMOUNT;
    *user_data = (DC_VOID *)udata;
    return(MNT_ERROR);
 }
#endif

 if ( !check_drive(remote_dir->mounted_fs) )
 {
   *udata = DO_NOT_UNMOUNT;
   *user_data = (DC_VOID *)udata;
   return(MNT_ERROR);
 }

 *user_data = (DC_VOID *)udata;
 return(MNT_OK);

}


DC_USHORT cx_unmount_fs   ( REMOTE_DIR    *remote_dir,
                            DC_VOID      **user_data,
                            DC_USHORT prot)
/*****************************************************************************/
/*                                                                           */
/* Description: This User-Exit is called by the agent to unmount a list of   */
/*              File System.                                                 */
/*              It is called at completion of the request.                   */
/*                                                                           */
/* Parameters:                                                               */
/*              *remote_dir    : remote directory to be unmounted            */
/*              **user_data    : user exit data. The same is passed          */
/*                               to the cx_unmount_fs user exit              */
/*              prot           : transport protocol (not used)               */
/*                                                                           */
/* Returns:     0   : File system successfully unmounted.                    */
/*                    An informational message is logged.                    */
/*              4   : File System to was not unmounted is only used          */
/*                    by DACA for messaging                                  */
/*              8   : An error was encountered unmounting the File System.   */
/*                    An error message is logged and the Operating System    */
/*                    error_code is returned in the output parameter errcode.*/
/*                                                                           */
/*****************************************************************************/
{
 DC_CHAR     unmount_cmd[sizeof(UNMOUNT) +
                         sizeof(DELETE)  +
                         sizeof(DC_FILE_NAME)];
 DC_USHORT     error;
 DC_USHORT     rc;
 DC_USHORT    *udata;

 rc = DC_OK;

 udata = *user_data;

/*****************************************************************************/
/* Set the parameter to pass to system call: this parameter contains the     */
/* command to be issued, in this case unmount (rmnfsmnt)                     */
/*****************************************************************************/

 if (*udata == DO_NOT_UNMOUNT)
 {
   free(*user_data);
   return(ALREADY_MOUNTED);
 }

 memset(unmount_cmd, '\0', (sizeof(UNMOUNT) +
                            sizeof(DELETE)  +
                            sizeof(DC_FILE_NAME)));

 strcpy(unmount_cmd, UNMOUNT);
 strcat(unmount_cmd, remote_dir->mounted_fs);
 strcat(unmount_cmd, DELETE);

 error = 0;
/*****************************************************************************/
/* Issue the command                                                         */
/*****************************************************************************/
#ifdef DVW32S_ENV
 error = exec_pgm(unmount_cmd);
 if (error <  32)
 {
   free(*user_data);
   return(UMNT_ERROR);
 }

#else
 error = system(unmount_cmd);
 if (error != 0)
 {
   free(*user_data);
   printf("BAD UNMOUNT\n");
   return(UMNT_ERROR);
 }
#endif



 free(*user_data);
 return(UMNT_OK);

}

