#ifndef __fndshop_h
#define __fndshop_h
/*****************************************************************************/
/*                                                                           */
/*    (C) COPYRIGHT IBM CORP 1995                                            */
/*    ALL RIGHTS RESERVED                                                    */
/*    LICENSED MATERIALS - PROPERTY OF IBM                                   */
/*                                                                           */
/* Product:         NetView Distribution Manager/6000                        */
/*                                                                           */
/* Module:          FNDSHOP.H                                                */
/*                                                                           */
/* Component:       DIVA Common                                              */
/*                                                                           */
/* Description:     Header defining the Common Format for Remote Operations. */
/*                                                                           */
/* Prerequisites:   fndhdr.h                                                 */
/*                                                                           */
/*****************************************************************************/

#include  <fndhdr.h>

typedef  DC_LONG  OPERATION_TYPE;
typedef  DC_LONG  ARGUMENT_TYPE;


/*****************************************************************************/
/* Structure: ARGUMENT_DEF                                                   */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure contains the information to describe a general type of   */
/*   argument can be passed to a function.                                   */
/*                                                                           */
/* Fields:                                                                   */
/*   type                                                                    */
/*     specifies the type of the argument.                                   */
/*                                                                           */
/*   size                                                                    */
/*     specifies the size of the argument.                                   */
/*                                                                           */
/*   value                                                                   */
/*     contains the argument as a byte stream structure. The filler must     */
/*     worry about the allocation of the needed memory to contain the        */
/*     argument.                                                             */
/*                                                                           */
/*****************************************************************************/
typedef struct argument_def
{
   ARGUMENT_TYPE  type;
   DC_ULONG       size;
   DC_CHAR        value[1];
}  ARGUMENT_DEF;


/*****************************************************************************/
/* Structure: OPERATION_DEF                                                  */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure contains the information to describe a general type of   */
/*   operation, through its type, number of arguments and arguments list     */
/*   which must be remotely executed.                                        */
/*                                                                           */
/* Fields:                                                                   */
/*   operation                                                               */
/*     specifies the type of the operation to be executed.                   */
/*                                                                           */
/*   arg_count                                                               */
/*     specifies the number of ARGUMENT_DEF structure contained following.   */
/*     array of ARGUMENT_DEF.                                                */
/*     specifies the number of the arguments contained in the following      */
/*     array of ARGUMENT_DEF.                                                */
/*                                                                           */
/*   arg_list                                                                */
/*     contains the list of arguments involved in the specified operation.   */
/*                                                                           */
/*****************************************************************************/
typedef struct operation_def
{
   OPERATION_TYPE  operation;
   DC_ULONG        arg_count; 
}  OPERATION_DEF;

/*****************************************************************************/
/* function prototype for special processing receiving report.               */
/*****************************************************************************/
typedef DC_SHORT (* FN_RPT_OPERATION)(DC_VOID        *tws,
                                      DC_VOID        *func_struct,
                                      ARGUMENT_DEF   *arg_struct);


/*****************************************************************************/
/* Structure: FN_RPT_OPERATION_ENTRY                                         */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure defines the entry in a set of functions required to be   */
/*   invoked according to a report.                                          */
/*                                                                           */
/* Fields:                                                                   */
/*   operation                                                               */
/*     The operation need to be executed for the arrived report              */
/*   funct_oper                                                              */
/*     function to process the arrived report                                */
/*                                                                           */
/*****************************************************************************/
typedef struct fn_rpt_operation_entry
{
  OPERATION_TYPE    operation;
  FN_RPT_OPERATION  funct_oper;
} FN_RPT_OPERATION_ENTRY;

#endif
