#ifndef __fndshrr_h
#define __fndshrr_h
/*****************************************************************************/
/*                                                                           */
/*    COPYRIGHT : 5765 - 196                                                 */
/*    (C) COPYRIGHT IBM CORP 1993                                            */
/*    ALL RIGHTS RESERVED                                                    */
/*    LICENSED MATERIALS - PROPERTY OF IBM                                   */
/*                                                                           */
/* Product:         NetView Distribution Manager/6000                        */
/*                                                                           */
/* Module:          FNDSHRR.H                                                */
/*                                                                           */
/* Component:       Request/Response formats                                 */
/*                                                                           */
/* Description:     This header defines the request and response formats     */
/*                  passed between the Server and the Client Agent.          */
/*                                                                           */
/* Prerequisites:   fndhdr.h                                                 */
/*                                                                           */
/*****************************************************************************/
/* WARNING!!!!!!!!!!!!!!!!!!!!!!!                              $C1A          */
/* vectores are ordered from 0x0000 to V_TOP_VECTOR.                         */
/* if you adds a new vector put it at the bottom of the list and update      */
/* V_TOP_VECTOR to reflect the new limit.                                    */
/* V_TOP_VECTOR is used in co_v_struc_ptr, co_search_vector and co_qend_ptr  */
/* to reject unrecognized vectors and is defined at the bottom of this file  */
/*****************************************************************************/
/* $C1=def10547 NWdev3270 31/10/96 AC : reject unrecognized vector type      */
/*****************************************************************************/
#include <fndhdr.h>
#include <fndshop.h>

/*****************************************************************************/
/* Structure: SCHED_TIME                                                     */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used to specify times in a format independent of      */
/*   changes to or from daylight savings time                                */
/*                                                                           */
/* Fields:                                                                   */
/*   date                                                                    */
/*     The date.                                                             */
/*   time                                                                    */
/*     The time of day.                                                      */
/*****************************************************************************/
typedef struct sched_time
{
  DVA_DATE     date;
  DVA_TIME     time;
} SCHED_TIME;

/*****************************************************************************/
/* Structure: TIME_WINDOW                                                    */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used to specify time windows in a format independent  */
/*   of changes to or from daylight savings time                             */
/*                                                                           */
/* Fields:                                                                   */
/*   notbef                                                                  */
/*     not before data & time                                                */
/*   notaft                                                                  */
/*     not after  date & time                                                */
/*   orig_dest                                                               */
/*     local time at origin or at destination                                */
/*     Valid values are: RR_ORIGIN_TIME                                      */
/*                       RR_DEST_TIME                                        */
/*****************************************************************************/
typedef struct time_window
{
   SCHED_TIME  notbef;
   SCHED_TIME  notaft;
   DC_USHORT   orig_dest;
   DC_USHORT   pad;
}  TIME_WINDOW;

#define  RR_ORIGIN_TIME  1
#define  RR_DEST_TIME    0

/*****************************************************************************/
/* Structure: TIME_INTERVAL                                                  */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used to specify time interval                         */
/*                                                                           */
/* Fields:                                                                   */
/*   years                                                                   */
/*   months                                                                  */
/*   days                                                                    */
/*   hours                                                                   */
/*   minutes                                                                 */
/*   seconds                                                                 */
/*****************************************************************************/
typedef struct time_interval
{
   DC_CHAR    years;
   DC_CHAR    months;
   DC_CHAR    days;
   DC_CHAR    hours;
   DC_CHAR    minutes;
   DC_CHAR    seconds;
}  TIME_INTERVAL;

/*****************************************************************************/
/* Structure: SCHEDULE_INFO                                                  */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure contains all the common fileds for requests, commands    */
/*   and reports                                                             */
/* Fields:                                                                   */
/*   submit_time                                                             */
/*     specifies the time the user submitted the request.                    */
/*     WARNING!!! this field was moved here from QUEUE_ENTRY_10              */
/*   sched_time                                                              */
/*     specifies the time RH submits the request to the scheduler.           */
/*     WARNING!!! this field was moved here from QUEUE_ENTRY_10              */
/*   exec_time_wnd                                                           */
/*     specifies the time window the request has to be executed at           */
/*     destination.                                                          */
/*     WARNING!!! part of this field was moved here from QUEUE_ENTRY_10      */
/*   appl_id                                                                 */
/*     is the identifier of the application that issued the request.         */
/*   rec_interval                                                            */
/*     specifies the recursion interval.                                     */
/*   rec_expir_time                                                          */
/*     specifies the date and time when the recursive request is stopped.    */
/*   rec_week_sched                                                          */
/*     specifies the week days the URH generates a new recursion.            */
/*   rec_month_sched                                                         */
/*     specifies the month days the request is to take place                 */
/*   term procedure                                                          */
/*     Procedure name to be executed when the request is completed           */
/*   term target                                                             */
/*     Name of the target where the term procedure must be executed          */
/*   flags                                                                   */
/*     They indicate the initial status of the Request. The values are:      */
/*          REQ_FLAG_RELEASED    released state (default)                    */
/*          REQ_FLAG_HELD        hold state                                  */
/*   priority_request                                                        */
/*     TRUE  - this request has been scheduled as a priority request         */
/*     FALSE - this request has not been scheduled as a priority request     */
/*     WARNING!!! this field was moved here from QUEUE_ENTRY_10              */
/*   superuser                                                               */
/*     Flag if user issuing request has ability to authorize the target      */
/*     for a file that is to be distributed to it.                           */
/*     WARNING!!! this field was moved here from QUEUE_ENTRY_10              */
/*   recgen_max_severity                                                     */
/*     It is the max severity of a recursive request according to a new      */
/*     recursion can be generated                                            */
/*   recgen_continue                                                         */
/*     TRUE  -  The recursion must continue if the previous instance has     */
/*               not been executed                                           */
/*     FALSE -  The recursion must be stopped if the previous instance has   */
/*               not been executed                                           */
/*****************************************************************************/
#define RQ_RECGEN_STOP  (DC_USHORT)0
#define RQ_RECGEN_CONT  (DC_USHORT)1
#define RQ_PRTY_LOW     (DC_USHORT)0
#define RQ_PRTY_HIGH    (DC_USHORT)1
typedef struct schedule_info
{
   SCHED_TIME     submit_time;
   SCHED_TIME     sched_time;
   TIME_WINDOW    exec_time_wnd;
#define DVA_APPLID_LEN    16
   DC_CHAR        appl_id[DVA_APPLID_LEN];
   DC_CHAR        rec_week_sched;
   DC_USHORT      rec_type;
   TIME_INTERVAL  rec_interval;
   DC_ULONG       rec_month_sched;
   SCHED_TIME     rec_expir_time;
   DC_GLOB        term_procedure;
   TARGET_NAME    term_target;
   DC_ULONG       flags;
   DC_USHORT      priority_request;
   DC_SHORT       superuser;
   DC_USHORT      recgen_max_severity;
   DC_USHORT      recgen_continue;
}  SCHEDULE_INFO;

/*****************************************************************************/
/* Values for flags field                                                    */
/*****************************************************************************/
#define RQ_FLAG_RELEASED        0x00000001
#define RQ_FLAG_HELD            0x00000002
#define RQ_FLAG_DELETED         0x00000004
#define RQ_FLAG_RELEASING       0x00000008
#define RQ_FLAG_HOLDING         0x00000010
#define RQ_FLAG_DELETING        0x00000020
#define RQ_FLAG_DEL_STOP_REC    0x00000040
#define RQ_FLAG_ADD_REC         0x00000080

/*****************************************************************************/
/* Values for rec_type field                                                 */
/*****************************************************************************/
#define RQ_NO_RECURSION       0
#define RQ_DATE_INTERVAL      1
#define RQ_TIME_INTERVAL      2
#define RQ_WEEK_SCHEDULE      3
#define RQ_MONTH_SCHEDULE     4

/*****************************************************************************/
/* Structure: CANCEL_REQ_10                                                  */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is written to the Schedule to request that another       */
/*   request be cancelled.                                                   */
/*                                                                           */
/* Fields:                                                                   */
/*   originator                                                              */
/*     Originator of the original request.                                   */
/*   destination                                                             */
/*     Destination of the original request.                                  */
/*   seq_no                                                                  */
/*     Sequence number of the original request.                              */
/*   submit_date                                                             */
/*     Date on which the original request was submitted.                     */
/*****************************************************************************/
typedef struct cancel_req_10
{
  DC_CHAR         originator[DVA_TRGNAME_LEN];
  DC_CHAR         destination[DVA_TRGNAME_LEN];
  DC_ULONG        seq_no;
  DVA_DATE        submit_date;
} CANCEL_REQ_10;

/* Moved REQUEST_ID back to fndcotyp.h to resolve new dependency             */
/* in SH_TGT_CONFIG                                                          */

/*****************************************************************************/
/* Structure: CANCEL_REQ                                                     */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used to request that another request be cancelled     */
/*                                                                           */
/* Fields:                                                                   */
/*   req_id                                                                  */
/*     the identifier of the original request.                               */
/*   subreq_id                                                               */
/*     sub-request identifier                                                */
/*     It makes sense for request sequences (it is always "0..0" for simple  */
/*     requests)                                                             */
/*****************************************************************************/
typedef struct cancel_req
{
   REQUEST_ID req_id;
   DC_CHAR    subreq_id[DVA_REQID_LEN];
}  CANCEL_REQ;

/*****************************************************************************/
/* Structure: HOLD_REL_REQ                                                   */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used to request that another request                  */
/*   be held or released                                                     */
/*                                                                           */
/* Fields:                                                                   */
/*   req_id                                                                  */
/*     the identifier of the original request.                               */
/*   subreq_id                                                               */
/*     sub-request identifier                                                */
/*     It makes sense for request sequences (it is always "0..0" for simple  */
/*     requests)                                                             */
/*****************************************************************************/
typedef struct hold_rel_req
{
   REQUEST_ID req_id;
   DC_CHAR    subreq_id[DVA_REQID_LEN];
}  HOLD_REL_REQ;


/*****************************************************************************/
/* Structure: RESCHEDULE_REQ                                                 */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used to request that another request be rescheduled   */
/*                                                                           */
/* Fields:                                                                   */
/*   req_id                                                                  */
/*     the identifier of the original request.                               */
/*   subreq_id                                                               */
/*     sub-request identifier                                                */
/*     It makes sense for request sequences (it is always "0..0" for simple  */
/*     requests)                                                             */
/*   sched_info                                                              */
/*     the structure wich contains the parameters will be updated            */
/*   rec_month_sched                                                         */
/*     specifies the month days the request is to take place                 */
/*****************************************************************************/
typedef struct reschedule_req
{
   REQUEST_ID     req_id;
   DC_CHAR        subreq_id[DVA_REQID_LEN];
   SCHEDULE_INFO  sched_info;
}  RESCHEDULE_REQ;

/*****************************************************************************/
/* Structure: RESET_REQ                                                      */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used to restart an already completed request for all  */
/*   targets whose target-error-level is higher or equal to a value passed   */
/*   as argument.                                                            */
/*                                                                           */
/* Fields:                                                                   */
/*   req_id                                                                  */
/*     the identifier of the original request.                               */
/*   error_level                                                             */
/*     specifies the minimum error_level for which the request has to  be    */
/*     restarted                                                             */
/*****************************************************************************/
typedef struct reset_req
{
   REQUEST_ID req_id;
   DC_USHORT  error_level;
}  RESET_REQ;

/*****************************************************************************/
/* Structure: INSTALL_REQ                                                    */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is passed to RB_SCHED_REQUEST to request                 */
/*   installation of up to 7 named change files.                             */
/*                                                                           */
/* Fields:                                                                   */
/*   cf_coreq                                                                */
/*     global names of up to 6 corequisite change files to install.  All     */
/*     unused global names must be initialised by co_init_glob.              */
/*   pre_test                                                                */
/*     specifies whether a pre-test is to be performed. Values               */
/*     listed below.                                                         */
/*   post_test                                                               */
/*     specifies whether a post_test is to be performed.  Values             */
/*     listed below.                                                         */
/*   auto_remove                                                             */
/*     specifies whether removably installed changes should automatically    */
/*     be backed out if the install fails. Values listed below.              */
/*   removability                                                            */
/*     specifies whether the installation should be removable, i.e.          */
/*     whether overwritten files should first be backed up. Values           */
/*     listed below.                                                         */
/*   auto_accept                                                             */
/*     specifies whether any backups should automatically be deleted         */
/*     on succesful install. Only used if installation is removable.         */
/*     Values listed below.                                                  */
/*   activation_use                                                          */
/*     specifies whether to install on trial or in production.               */
/*     Values listed below.                                                  */
/*   alter_active                                                            */
/*     specifies whether to install into the service or active               */
/*     area. Values listed below.                                            */
/*   disposition                                                             */
/*     specifies whether to delete the change file from the server's         */
/*     catalog, after successful installation on all targets. Values         */
/*     listed below.                                                         */
/*   object_class                                                            */
/*     data object class of change file. Values are from Appendix E of the   */
/*     SNA/FS Reference manual.                                              */
/*   force_exec                                                              */
/*     specifies whether to force the install (i.e. skip the state and       */
/*     maintenance level checks).  Values listed below.                      */
/*   extend_jfs                                                              */
/*     specifies whether journaled file systems should be extended if        */
/*     required during the installation. Values listed below.                */
/*                                                                           */
/*****************************************************************************/
typedef struct install_req
{
  DC_GLOB       cf_coreq[DVA_NUM_COREQS];
  DC_USHORT     pre_test;
  DC_USHORT     post_test;
  DC_USHORT     auto_remove;
  DC_USHORT     removability;
  DC_USHORT     auto_accept;
  DC_USHORT     activation_use;
  DC_USHORT     alter_active;
  DC_USHORT     disposition;
  DC_ULONG      object_class;
  DC_USHORT     force_exec;
  DC_USHORT     extend_jfs;
  DC_USHORT     pad;
} INSTALL_REQ;

/*****************************************************************************/
/* Values for pre_test and post_test fields                                  */
/*****************************************************************************/
#define TEST_YES       0x10       /* do pre/post test                        */
#define TEST_DESIRED   0x20       /* perform pre/post if possible to perform */
#define TEST_NO        0x30       /* no pre/post-test used                   */

/*****************************************************************************/
/* Values for auto_remove field                                              */
/*****************************************************************************/
#define AR_YES         0x10       /* install is backed out on failure        */
#define AR_DESIRED     0x20       /* auto_remove is desired                  */
#define AR_NO          0x30       /* install is not backed out on failure    */
#define AR_NOT_USED    0xff       /* not relevant (removability prohibited)  */

/*****************************************************************************/
/* Values for removability field                                             */
/*****************************************************************************/
#define REM_YES        0x10       /* install can be backed out               */
#define REM_DESIRED    0x20       /* removability is desired                 */
#define REM_NO         0x30       /* install cannot be backed out            */

/*****************************************************************************/
/* Values for auto_accept field                                              */
/*****************************************************************************/
#define AA_YES         0x10       /* backups deleted on succesful install    */
#define AA_DESIRED     0x20       /* auto_accept is desired                  */
#define AA_NO          0x30       /* backups not deleted on succesful install*/
#define AA_NOT_USED    0xff       /* not relevant (removability prohibited)  */

/*****************************************************************************/
/* Values for activation_use field                                           */
/*****************************************************************************/
#define AU_TRIAL       0x10      /* install on trial                         */
#define AU_PRODUCT     0x20      /* install in production                    */

/*****************************************************************************/
/* Values for alter_active field                                             */
/*****************************************************************************/
#define AL_YES         0x20      /* install in active area                   */
#define AL_NO          0x30      /* install in servive area                  */

/*****************************************************************************/
/* Values for disposition field                                              */
/*****************************************************************************/
#define INST_KEEP      0x10      /* keep change file in server's catalog     */
#define INST_DELETE    0x30      /* delete change file from server's catalog */
                                 /* after successful installs on all targets */


/*****************************************************************************/
/* Values for force_exec  field                                              */
/*****************************************************************************/
#define FE_YES         0x10       /* bypass state checks                     */
#define FE_DESIRED     0x20       /* bypass state checks                     */
#define FE_NO          0x30       /* don't bypass state checks               */

/*****************************************************************************/
/* Values for extend_jfs  field                                              */
/*****************************************************************************/
#define EXJFS_YES      0x10     /* extend journaled file systems if required */
#define EXJFS_DESIRED  0x20     /* extend JFS if required                    */
#define EXJFS_NO       0x30     /* don't extend journaled file systems       */
#define EXJFS_NOT_REQ  0xff     /* extend journaled file syetems sub vector  */
                                /* was not specified                         */


/*****************************************************************************/
/* Structure: EXT_CM_STATUS                                                  */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is part of the updcm request containing the internal     */
/*   CM value that should be assigned to the resource.                       */
/*   It contains three characters that are not used, for now. They will be   */
/*   used if the structure of the cm status will be enlarged.                */
/* Fields:                                                                   */
/*   cm_not_used                                                             */
/*     See description above.                                                */
/*   cm_int_value                                                            */
/*     this field contains the new CM status that should be overwritten      */
/*                                                                           */
/*****************************************************************************/
typedef struct  ext_cm_status
{
  DC_CHAR       cm_not_used[3];
  DC_CHAR       cm_int_value;
} EXT_CM_STATUS;

/*****************************************************************************/
/* Structure: UPDCM_REQ                                                      */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is passed to RB_SCHED_REQUEST to request                 */
/*   the updating of the CM status of an object for one or more targets.     */
/*                                                                           */
/* Fields:                                                                   */
/*   object_class                                                            */
/*     data object class of change file. Values are from Appendix E of the   */
/*     SNA/FS Reference manual.                                              */
/*   force_exec                                                              */
/*     this field contains the force parameter, if the user wants to change  */
/*     the CM status without considering the previous cm status.             */
/*   action                                                                  */
/*     rebooted or activated if these parameters have been specified in      */
/*     updcm. The values are described below.                                */
/*   cm_status                                                               */
/*     this field contains the new CM status that should be overwritten      */
/*                                                                           */
/*****************************************************************************/
typedef struct  updcm_req
{
  DC_ULONG      object_class;
  DC_USHORT     force_exec;
  DC_CHAR       action;
  DC_CHAR       pad;
  EXT_CM_STATUS cm_status;
} UPDCM_REQ;


#define UPDCM_ACTIVATED     (DC_CHAR)1
                                  /* the -n parameter of updcm is "activated"*/

#define UPDCM_REBOOTED      (DC_CHAR)2
                                  /* the -n parameter of updcm is "rebooted" */

#define UPDCM_DISTRIBUTED   (DC_CHAR)3
                                 /* the -n parameter of updcm is distributed */

/*****************************************************************************/
/* Structure: REMOVE_REQ                                                     */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is passed to RB_SCHED_REQUEST to request                 */
/*   backing out of the named change file (and any corequisites              */
/*   that were installed with it). A change file can be removed only         */
/*   if it was installed removably (i.e. with removability field set         */
/*   to INST_REMOVABLE) and has not yet been accepted.                       */
/*                                                                           */
/* Fields:                                                                   */
/*   post_test                                                               */
/*     specifies whether a post_test is required.  Values                    */
/*     listed above (after INSTALL_REQ definition).                          */
/*   alter_active                                                            */
/*     specifies whether to reinstate the backup copy from the service       */
/*     area. Values listed above (after INSTALL_REQ definition).             */
/*   object_class                                                            */
/*     data object class of change file. Values are from Appendix E of the   */
/*     SNA/FS Reference manual.                                              */
/*   active_status                                                           */
/*     is the Change File currently installed in the Active Area? Values     */
/*     listed below.                                                         */
/*                                                                           */
/*****************************************************************************/
typedef struct remove_req
{
  DC_USHORT     post_test;
  DC_USHORT     alter_active;
  DC_ULONG      object_class;
  DC_USHORT     active_status;
  DC_USHORT     pad;
} REMOVE_REQ;

/*****************************************************************************/
/* Values for active_status field                                            */
/*****************************************************************************/
#define AS_YES         0x20      /* installed in active area                 */
#define AS_NO          0x30      /* installed in servive area                */


/*****************************************************************************/
/* Structure: ACCEPT_REQ                                                     */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is passed to RB_SCHED_REQUEST to request acceptance      */
/*   of the named change file.                                               */
/*                                                                           */
/* Fields:                                                                   */
/*   object_class                                                            */
/*     data object class of change file. Values are from Appendix E of the   */
/*     SNA/FS Reference manual.                                              */
/*                                                                           */
/*****************************************************************************/
typedef struct accept_req
{
  DC_ULONG      object_class;
} ACCEPT_REQ;


/*****************************************************************************/
/* Structure: ACTIVATE_REQ                                                   */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is passed to RB_SCHED_REQUEST to request                 */
/*   activation. Activation of a target reboots that target; as this is      */
/*   undesirable on any target that is also a server, an activate            */
/*   request should not be sent to a server. Instead a post-install          */
/*   script should be used to activate a change on a server.                 */
/*                                                                           */
/* Fields:                                                                   */
/*   force                                                                   */
/*     specifies whether to perform the activation based on the quiesced     */
/*     state of the target node. Values listed below.                        */
/*   activation_use                                                          */
/*     specifies which installed changes to activate. Values listed below.   */
/*                                                                           */
/*****************************************************************************/
typedef struct activate_req
{
  DC_USHORT     force;
  DC_USHORT     activation_use;
} ACTIVATE_REQ;

/*****************************************************************************/
/* Values for force field                                                    */
/*****************************************************************************/
#define FO_NO          0x10      /* Do not force (reject if quiesced)        */
#define FO_YES         0x20      /* Force activation                         */

/*****************************************************************************/
/* Values for activation_use field                                           */
/*****************************************************************************/
#define AC_TANDP       0x10      /* activate trial and production            */
#define AC_PRODUCT     0x20      /* activate production only                 */
#define AC_NOT_USED    0xff      /* activation use subvector was not         */
                                 /* specified                                */


/*****************************************************************************/
/* Structure: INITIATE_REQ                                                   */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is passed to RB_SCHED_REQUEST to request                 */
/*   initiation.                                                             */
/*                                                                           */
/* Fields:                                                                   */
/*   params                                                                  */
/*     parameter string to use when invoking proc. Must be                   */
/*     null-terminated.                                                      */
/*   disposition                                                             */
/*     specifies whether to delete the procedure from the server's           */
/*     catalog, after successful initiation of all targets. Values           */
/*     listed below.                                                         */
/*   object_class                                                            */
/*     data object class of command file. Values are from Appendix E of the  */
/*     SNA/FS Reference manual.                                              */
/*                                                                           */
/*****************************************************************************/
typedef struct initiate_req
{
  DC_CHAR       params[DVA_IPARAMS_LEN];
  DC_USHORT     disposition;
  DC_USHORT     pad;
  DC_ULONG      object_class;
} INITIATE_REQ;

/*****************************************************************************/
/* Values for disposition field                                              */
/*****************************************************************************/
#define INIT_KEEP      0x01      /* keep command file in server's catalog    */
#define INIT_DELETE    0x03      /* delete command file from server's catalog*/
                                 /* after successful initiates on all        */
                                 /* targets                                  */


/*****************************************************************************/
/* Structure: DELETE_REQ                                                     */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is passed to RB_SCHED_REQUEST to request deletion.       */
/*                                                                           */
/* Fields:                                                                   */
/*   except_action                                                           */
/*     specifies how exceptions are to be handled at DACA. Values            */
/*     listed below.                                                         */
/*                                                                           */
/*****************************************************************************/
typedef struct delete_req
{
  DC_USHORT     except_action;
  DC_USHORT     pad;
} DELETE_REQ;

/*****************************************************************************/
/* Values for except_action field                                            */
/*****************************************************************************/
#define EX_BACKOUT      1        /* backout file action                      */
#define EX_ABEND        2        /* abort without backout                    */


/*****************************************************************************/
/* Structure: FETCH_STORE_REQ                                                */
/*                                                                           */
/* Overview:                                                                 */
/*   This is the common structure for fetch requests (FETCH_REQ) and         */
/*   store requests (STORE_REQ).                                             */
/*   The information required for the two request types is almost exactly    */
/*   the same, and use of a common structure simplifies code which deals     */
/*   with both request types (especially in RH).                             */
/*   NB: V2R0 code relies on FETCH_REQ and STORE_REQ having a common         */
/*       structure - future changes should be made to FETCH_STORE_REQ        */
/*       rather than to FETCH_REQ or STORE_REQ separately.                   */
/*                                                                           */
/* Fields:                                                                   */
/*   except_action                                                           */
/*     specifies how exceptions are to be handled at DACA.                   */
/*     Values listed above (after definition of DELETE_REQ).                 */
/*   replace                                                                 */
/*     specifies whether to replace an existing file or create a new one.    */
/*     Values listed below.                                                  */
/*   src_compress                                                            */
/*     specifies if Source needs to perform compression/decompression.       */
/*     Values listed below.                                                  */
/*   tgt_compress                                                            */
/*     specifies if Target needs to perform compression/decompression.       */
/*     Values listed below.                                                  */
/*   compression                                                             */
/*     specifies compression algorithm to be used.                           */
/*                                                                           */
/*   ccsid                                                                   */
/*     CCSID of data file.  0 if the file is not a text file.                */
/*     This is not necessarily the same as cat_entry.utc_ccsid               */
/*     (the INTENDED CCSID).                                                 */
/*     Used in fetch reports and store requests but not in fetch             */
/*     requests.                                                             */
/*   cat_entry                                                               */
/*     specifies all catalog info.  It is used by STS to transfer files      */
/*     between different servers.  For send and retrieve of cataloged        */
/*     files this is the source catalog entry, before any source             */
/*     compression actions.                                                  */
/*   local_file_offset                                                       */
/*     is used for restart recovery.                                         */
/*   remote_file_offset                                                      */
/*     is used for restart recovery.                                         */
/*                                                                           */
/*****************************************************************************/
typedef struct fetch_store_req
{
  DC_USHORT     except_action;
  DC_USHORT     replace;
  DC_USHORT     src_compress;
  DC_USHORT     tgt_compress;
  DC_COMPRESS   compression;
  DC_USHORT     pad;
  DC_USHORT     ccsid;
  CAT_ENTRY     cat_entry;
  DC_ULONG      local_file_offset;
  DC_ULONG      remote_file_offset;
} FETCH_STORE_REQ;


/*****************************************************************************/
/* Structure: STORE_REQ                                                      */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used for store requests.                              */
/*   File transfer requests (send and retrieve) are processed as a fetch     */
/*   request followed by a store request.                                    */
/*   STORE requests should only ever be issued by NGA or RH (Scheduler in    */
/*   earlier releases).  The UI always uses a FETCH request (see below)      */
/*   specifying the source and target for the file.                          */
/*                                                                           */
/*****************************************************************************/
typedef FETCH_STORE_REQ STORE_REQ;

/*****************************************************************************/
/* Values for replace field                                                  */
/*****************************************************************************/
#define RE_REPLACE_ONLY       1  /* must replace existing file               */
#define RE_CREATE_ONLY        2  /* must not exist already                   */
#define RE_CR_OR_REPLACE      3  /* replace existing file - otherwise create */

/*****************************************************************************/
/* Values for src_compress and tgt_compress fields                           */
/*****************************************************************************/
#define CP_NONE               0  /* fetch/store as is                        */
#define CP_COMPRESS           1  /* compress the file using algorithm given  */
#define CP_DECOMPRESS         2  /* decompress using algorithm given         */

/*****************************************************************************/
/* Values for trans_len_data field                                           */
/*****************************************************************************/
#define TR_UNDECIDED          0  /* undecided - this is the initial value    */
                                 /* which is converted by the Scheduler to   */
                                 /* TR_DONT_TRANS or TR_DO_TRANS before the  */
                                 /* request is passed to DACA                */
                                 /* NB: 0 chosen for initial value           */
#define TR_DONT_TRANS         1  /* do translate between length data format  */
                                 /* and local format                         */
#define TR_DO_TRANS           2  /* do not translate between length data     */
                                 /* format and local format                  */


/*****************************************************************************/
/* Structure: FETCH_REQ                                                      */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used for fetch requests.  It is passed to             */
/*   RB_SCHED_REQUEST to request file transfer (send or retrieve).           */
/*                                                                           */
/*   All file transfer requests are processed as a fetch request to the      */
/*   file source followed by a store request to the file destination.        */
/*   RH (Scheduler in earlier releases) issues the store request when        */
/*   it receives the fetch report.                                           */
/*                                                                           */
/*   When a fetch request is received from a remote server (as the first     */
/*   part of a retrieve), the fetch is processed and a fetch report is       */
/*   sent back.  The originating server then issues the fetch report when    */
/*   it receives the fetch report.  Thus the fetch report is converted to    */
/*   a store request at the originating server, not at the file source       */
/*   server.                                                                 */
/*                                                                           */
/*   In V2R0 fetch requests are also used to transfer files between servers  */
/*   (STS file transfer).                                                    */
/*                                                                           */
/*   The ccsid field is not used in fetch requests - the cat_entry.utc_ccsid */
/*   field is used instead (but ccsid is set in fetch reports, and differs   */
/*   from cat_entry.utc_ccsid when the latter is DVA_CCSID_NATIVE).          */
/*                                                                           */
/*   Unlike earlier releases, V2R0 does not require the origin_group field   */
/*   to support sending a file to a group of targets.                        */
/*                                                                           */
/*****************************************************************************/
typedef FETCH_STORE_REQ FETCH_REQ;


/*****************************************************************************/
/* Structure: SND_INSTALL_REQ                                                */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is passed to RB_SCHED_REQUEST to request the storing     */
/*   and installation of a Change File.                                      */
/*                                                                           */
/* Fields:                                                                   */
/*   store                                                                   */
/*     specifies how the accompanying file is to be processed. See STORE_REQ */
/*     above for definition of fields and values.                            */
/*   install                                                                 */
/*     specifies the parameters for the install process. See INSTALL_REQ     */
/*     above for definition of fields and values.                            */
/*                                                                           */
/*****************************************************************************/
typedef struct snd_install_req
{
  STORE_REQ     store;
  INSTALL_REQ   install;
} SND_INSTALL_REQ;


/*****************************************************************************/
/* Structure: SND_INITIATE_REQ                                               */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is passed to RB_SCHED_REQUEST to request the storing     */
/*   and initiation of a procedure.                                          */
/*                                                                           */
/* Fields:                                                                   */
/*   store                                                                   */
/*     specifies how the accompanying file is to be processed. See STORE_REQ */
/*     above for definition of fields and values.                            */
/*   install                                                                 */
/*     specifies the parameters for the initiate process. See INITIATE_REQ   */
/*     above for definition of fields and values.                            */
/*                                                                           */
/*****************************************************************************/
typedef struct snd_initiate_req
{
  STORE_REQ     store;
  INITIATE_REQ  initiate;
} SND_INITIATE_REQ;


/*****************************************************************************/
/* Structure: UNINSTALL_REQ                                                  */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is passed to RB_SCHED_REQUEST to request the             */
/*   uninstallation of up to 7 named change files.                           */
/*                                                                           */
/* Fields:                                                                   */
/*   alter_active                                                            */
/*     specifies whether to uninstall into the service or active             */
/*     area. Values listed above.                                            */
/*   force                                                                   */
/*     specifies whether to perform the uninstall based on the quiesced      */
/*     state of the target node. Values listed above.                        */
/*   object_class                                                            */
/*     data object class of command file. Values are from Appendix E of the  */
/*     SNA/FS Reference manual.  (this is filled in by the scheduler since   */
/*     it is not part of the SNA/MS request but is part of the report)       */
/*                                                                           */
/*****************************************************************************/
typedef struct uninstall_req
{
  DC_USHORT     alter_active;
  DC_USHORT     force;
  DC_ULONG      object_class;
} UNINSTALL_REQ;


/*****************************************************************************/
/* Structure: EXECPLAN_REQ                                                   */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is passed to RB_SCHED_REQUEST to request                 */
/*   the execution of a plan.                                                */
/*                                                                           */
/* Fields:                                                                   */
/*   params                                                                  */
/*     parameter string to use to resolve variables ($1, ...$n) in the       */
/*     plan.                                                                 */
/*   disposition                                                             */
/*     specifies whether to delete the sequence from the server's            */
/*     catalog, after successful execution of all targets. Values            */
/*     listed above (SEE INITIATE_REQ)                                       */
/*   object_class                                                            */
/*     data object class of command file. Values are from Appendix E of the  */
/*     SNA/FS Reference manual.                                              */
/*                                                                           */
/*****************************************************************************/
typedef struct execplan_req
{
  DC_CHAR       params[DVA_IPARAMS_LEN];
  DC_USHORT     disposition;
  DC_USHORT     pad;
  DC_ULONG      object_class;
} EXECPLAN_REQ;


/*****************************************************************************/
/* Structure: OPEN_CONN_WIN_REQ                                              */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by DACA on mobile clients to control the         */
/*   resynchronisation of databases.                                         */
/*                                                                           */
/* Fields:                                                                   */
/*   type                                                                    */
/*     Whether the client is to upload reports or resync databases.          */
/*                                                                           */
/*****************************************************************************/
typedef struct open_conn_win_req
{
  DC_USHORT     type;
} OPEN_CONN_WIN_REQ;

/*****************************************************************************/
/* Values for type field. THE VALUES MUST BE bitwise                         */
/*****************************************************************************/
#define SH_OPEN_TYPE_REPORTS    1
#define SH_OPEN_TYPE_RESYNC     2
#define SH_OPEN_TYPE_OUTSTANDING   4
#define SH_OPEN_DEF_CONNECTION     8


/*****************************************************************************/
/* Structure: CLOSE_CONN_WIN_REQ                                             */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by UI to inform the server which kind of CLOSE   */
/*   must be executed.                                                       */
/*                                                                           */
/* Fields:                                                                   */
/*   type                                                                    */
/*     Whether the close connection must be reset the recursion mechanism    */
/*     or not.                                                               */
/*                                                                           */
/*****************************************************************************/
typedef struct close_conn_win_req
{
  DC_USHORT     execute;
} CLOSE_CONN_WIN_REQ;

/*****************************************************************************/
/* Values for 'execute' field.                                               */
/*****************************************************************************/
#define CLOSE_CONNECT_ONLY      1
#define CLOSE_RECURS_CONNECT    2
#define DISCONNECT_AND_RESET    4
#define OPEN_TYPE_OUTSTANDING   8
#define DEFAULT_CONN_WINDOW    16


/*****************************************************************************/
/* Structure: DC_STATUS                                                      */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is included at the top of every report structure and     */
/*   indicates success/failure of the main request.                          */
/*                                                                           */
/* Fields:                                                                   */
/*   status                                                                  */
/*     Status of the install request. Values listed below.                   */
/*   destructive                                                             */
/*     This flag is set whenever DACA could not complete or backout the      */
/*     operation, and has already performed destructive disk operations. It  */
/*     is FALSE otherwise.                                                   */
/*     Currently, this flag is only meaningful for Change Control reports    */
/*     (Install, Uninstall, Accept, Remove and Activate). Its value is       */
/*     ignored for all other request types                                   */
/*   sense_code1                                                             */
/*     primary sense code from DACA. This will be zero if no error to report */
/*   sense_code2                                                             */
/*     secondary sense code from DACA. This will be zero if no error to      */
/*     report                                                                */
/*                                                                           */
/* Further explanation of status and destructive fields                      */
/* ====================================================                      */
/*                                                                           */
/* The values for the status field include two different encodings for       */
/* failed requests - ST_FAILED_RECOV and ST_FAILED_NOREC.  Together with     */
/* the destructive flag this gives 3 encodings for failed requests:          */
/*   status = ST_FAILED_RECOV, destructive = FALSE                           */
/*   status = ST_FAILED_NOREC, destructive = FALSE                           */
/*   status = ST_FAILED_NOREC, destructive = TRUE                            */
/* (the 4th possibility doesn't make sense).                                 */
/* Unfortunately there is no SNA/MS encoding for the destructive flag, so it */
/* is impossible to distinguish between these 3 encodings when sending a     */
/* SNA/MS format report to the Remote Admin Site.                            */
/* For change control reports this is important, because the destructive     */
/* flag (together with other fields) determines how CM status is updated.    */
/* This problem can be avoided by using only 2 of the encodings:             */
/*   status = ST_FAILED_RECOV, destructive = FALSE                           */
/*   status = ST_FAILED_NOREC, destructive = TRUE                            */
/* so that the status field (which does have a SNA/MS encoding) implies the  */
/* setting of the destructive field.                                         */
/*                                                                           */
/* In the case of install reports the situation is complicated by the        */
/* possiblity of successful installation followed by an error during         */
/* automatic acceptance.  In this case we have                               */
/*   status = ST_OK, aa_status = AA_FAILED, destructive = TRUE               */
/* Thus status ST_OK with auto-accept status AA_FAILED must be treated in    */
/* the same way as overall status ST_FAILED_NOREC.  The setting of the       */
/* destructive flag is then equivalent to the condition                      */
/*                                                                           */
/*  (status == ST_FAILED_NOREC) ||                                           */
/*  ((status == ST_OK) && (aa_status == AA_FAILED))                          */
/*                                                                           */
/* It is impossible retrospectively to make 1.0 clients follow this rule,    */
/* so THE SCHEDULER TRANSLATES THE STATUS FIELD AND DESTRUCTIVE FLAG in      */
/* order to enforce it.                                                      */
/*                                                                           */
/* Note that the destructive flag is meaningful only for change control      */
/* reports - for other reports it is ignored and there is no need to tie the */
/* encoding of the status field to the destructive flag.                     */
/*                                                                           */
/*****************************************************************************/
typedef struct dc_status
{
  DC_USHORT     status;
  DC_USHORT     destructive;
  DC_USHORT     sense_code1;
  DC_USHORT     sense_code2;
} DC_STATUS;

/*****************************************************************************/
/* Values for status field                                                   */
/*****************************************************************************/
#define ST_OK            0x00      /* Request succeeded                      */
#define ST_FAILED_RECOV  0x01      /* Request failed - recovery effected     */
#define ST_FAILED_NOREC  0x02      /* Request failed - recovery not effected */
#define ST_NO_ATTEMPT    0x03      /* Not attempted and will not attempt     */
#define ST_WILL_ATTEMPT  0x04      /* Will attempt it at requested time      */
#define ST_BAD_REQUEST   0xFF      /* The request type is unrecognised       */



/*****************************************************************************/
/* Structure: INSTALL_RPT                                                    */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by D&CC Agents to report                         */
/*   on the progress of a INSTALL_REQ change management request.             */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of the install request.  Values listed under DC_STATUS above.  */
/*   cf_coreq                                                                */
/*     Corequisite change files removed.                                     */
/*   effective                                                               */
/*     Specifies when the changes will be effective.  Values listed below.   */
/*   pre_test                                                                */
/*     Specifies status of pre-test.  Values listed below.                   */
/*   post_test                                                               */
/*     Specifies status of post-test.  Values listed below.                  */
/*   ar_status                                                               */
/*     Auto removal status.  Values listed below.                            */
/*   ar_effective                                                            */
/*     Specifies when autoremoval is / will be effective.  Values            */
/*     listed below.                                                         */
/*   aa_status                                                               */
/*     Auto accept status.  Values listed below.                             */
/*   r_status                                                                */
/*     Removability status.  Values listed below.                            */
/*   act_status                                                              */
/*     activation use status.  Values listed below.                          */
/*   disposition                                                             */
/*     value of disposition from the install request (values listed          */
/*     under INSTALL_REQ above).                                             */
/*   force status                                                            */
/*     result of the force of the install.  Values listed below              */
/*   extended_jfs                                                            */
/*     specifies whether journaled file systems were extended during the     */
/*     installation. Values listed below                                     */
/*   reboot_required       NOT USED - extra value for effective field        */
/*     specifies whether a reboot is required to activate the changes made.  */
/*     Values listed below                                                   */
/*   force status                                                            */
/*     result of the force of the install.  Values listed below              */
/*   object_class                                                            */
/*     data object class of change file.  Values are from Appendix E of the  */
/*     SNA/FS Reference manual.                                              */
/*   local_rc                                                                */
/*     return code from DACA.  Values are from the HLD for DACA.             */
/*   error_file                                                              */
/*     Global file name of a file to be reported on in the event of an       */
/*     error.                                                                */
/*                                                                           */
/*****************************************************************************/
typedef struct install_rpt
{
  DC_STATUS     result;
  DC_GLOB       cf_coreq[DVA_NUM_COREQS];
  DC_USHORT     effective;
  DC_USHORT     pre_test;
  DC_USHORT     post_test;
  DC_USHORT     ar_status;
  DC_USHORT     ar_effective;
  DC_USHORT     aa_status;
  DC_USHORT     r_status;
  DC_USHORT     act_status;
  DC_USHORT     disposition;
  DC_USHORT     force_status;
  DC_USHORT     extended_jfs;
  DC_USHORT     reboot_required;
  DC_ULONG      object_class;
  DC_ULONG      local_rc;
  DC_GLOB       error_file;
} INSTALL_RPT;

/*****************************************************************************/
/* Values for effective field                                                */
/*****************************************************************************/
#define EF_IN_USE        0x10       /* installed changes are in use          */
#define EF_DISCOVERED    0x18       /* changes are in use but discovered     */
                                    /* (Uninstallable)                       */
#define EF_ACT_REQUD     0x20       /* activate is required                  */
#define EF_REBOOT_REQ    0x28       /* reboot required to complete changes   */
#define EF_NA            0x30       /* not applicable                        */

/*****************************************************************************/
/* Values for pre_test and post_test fields                                  */
/*****************************************************************************/
#define TS_OK            0x10       /*   test was successful                 */
#define TS_FAILED        0x20       /*   test failed                         */
#define TS_NO_ATTEMPT    0x30       /*   test not attempted                  */
#define TS_NO_REQUEST    0xff       /*   not requested                       */

/*****************************************************************************/
/* Values for ar_status field                                                */
/*****************************************************************************/
#define AR_OK            0x10       /* autoremoval was successful            */
#define AR_FAILED_RECOV  0x20       /* a/r failed - recovery effected        */
#define AR_FAILED_NOREC  0x28       /* a/r failed - recovery not effected    */
#define AR_NO_ATTEMPT    0x30       /* autoremoval not attempted             */
#define AR_NO_REQUEST    0xff       /* autoremoval not requested             */

/*****************************************************************************/
/* Values for ar_effective field                                             */
/*****************************************************************************/
#define AR_IN_USE        0x10       /* changed components now in use         */
#define AR_ACT_REQUD     0x20       /* components changed - activation req   */
#define AR_NA            0x30       /* not applicable                        */

/*****************************************************************************/
/* Values for aa_status field                                                */
/*****************************************************************************/
#define AA_OK            0x10       /* autoaccept was successful             */
#define AA_FAILED        0x20       /* autoaccept failed                     */
#define AA_NO_ATTEMPT    0x30       /* autoaccept not attempted              */
#define AA_NO_REQUEST    0xff       /* autoaccept not requested              */

/*****************************************************************************/
/* Values for r_status field                                                 */
/*****************************************************************************/
#define R_REM            0x10       /* installed removably                   */
#define R_NON_REM        0x20       /* installed non-removably               */
#define R_NOT_INST       0x30       /* not installed                         */

/*****************************************************************************/
/* Values for act_status field                                               */
/*****************************************************************************/
#define ACT_TRIAL        0x10       /* installed in trial area               */
#define ACT_PROD         0x20       /* installed in production area          */
#define ACT_NOT_INST     0x30       /* installation was unsuccessful         */

/*****************************************************************************/
/* Values for force_status field                                             */
/*****************************************************************************/
#define FE_OK          0x10       /* force requested and successful          */
#define FE_FAILED      0x20       /* force requested but install failed      */
#define FE_NO_ATTEMPT  0x30       /* force not requested                     */

/*****************************************************************************/
/* Values for extended_jfs  field                                            */
/*****************************************************************************/
#define EXDJFS_YES     0x10     /* a journaled file system was extended      */
#define EXDJFS_NONE    0x30     /* no file systems were extended             */
#define EXDJFS_NO_REQ  0xff     /* not requested                             */

/*****************************************************************************/
/* Values for reboot_required field                                          */
/*****************************************************************************/
#define REB_NOT_REQ    0x10     /* reboot not required to activate changes   */
#define REB_REQ        0x20     /* reboot required to activate changes       */
#define REB_NA         0x30     /* not applicable                            */



/*****************************************************************************/
/* Structure: REMOVE_RPT                                                     */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by D&CC Agents to report                         */
/*   on the progress of a REMOVE_REQ change management request.              */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of the request. Values listed under DC_STATUS above.           */
/*   cf_coreq                                                                */
/*     Corequisite change files removed.                                     */
/*   effective                                                               */
/*     Specifies when the changes will be effective. Values listed under     */
/*     INSTALL_RPT above.                                                    */
/*   object_class                                                            */
/*     data object class of change file. Values are from Appendix E of the   */
/*     SNA/FS Reference manual.                                              */
/*   local_rc                                                                */
/*     return code from DACA. Values are from the HLD for DACA.              */
/*   error_file                                                              */
/*     Global file name of a file to be reported on in the event of an       */
/*     error.                                                                */
/*                                                                           */
/*****************************************************************************/
typedef struct remove_rpt
{
  DC_STATUS     result;
  DC_GLOB       cf_coreq[DVA_NUM_COREQS];
  DC_USHORT     effective;
  DC_CHAR       pad[2];
  DC_ULONG      object_class;
  DC_ULONG      local_rc;
  DC_GLOB       error_file;
} REMOVE_RPT;


/*****************************************************************************/
/* Structure: ACCEPT_RPT                                                     */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by D&CC Agents to report                         */
/*   on the progress of a ACCEPT_REQ change management request.              */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of the request. Values listed under DC_STATUS above).          */
/*   cf_coreq                                                                */
/*     Corequisite change files removed.                                     */
/*   object_class                                                            */
/*     data object class of change file. Values are from Appendix E of the   */
/*     SNA/FS Reference manual.                                              */
/*   local_rc                                                                */
/*     return code from DACA. Values are from the HLD for DACA.              */
/*   error_file                                                              */
/*     Global file name of a file to be reported on in the event of an       */
/*     error.                                                                */
/*                                                                           */
/*****************************************************************************/
typedef struct accept_rpt
{
  DC_STATUS     result;
  DC_GLOB       cf_coreq[DVA_NUM_COREQS];
  DC_ULONG      object_class;
  DC_ULONG      local_rc;
  DC_GLOB       error_file;
} ACCEPT_RPT;


/*****************************************************************************/
/* Structure: ACTIVATE_RPT                                                   */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by D&CC Agents to report                         */
/*   on the progress of a ACTIVATE_REQ change management request.            */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of the request. Values listed under DC_STATUS above).          */
/*   local_rc                                                                */
/*     return code from DACA. Values are from the HLD for DACA.              */
/*   error_file                                                              */
/*     Global file name of a file to be reported on in the event of an       */
/*     error.                                                                */
/*                                                                           */
/*****************************************************************************/
typedef struct activate_rpt
{
  DC_STATUS     result;
  DC_ULONG      local_rc;
  DC_GLOB       error_file;
} ACTIVATE_RPT;



/*****************************************************************************/
/* Structure: INITIATE_RPT                                                   */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by D&CC Agents to report                         */
/*   on the progress of a INITIATE_REQ change management request.            */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of the request. Values listed under DC_STATUS above).          */
/*   job_state                                                               */
/*     Flag whether the job has been run or just queued for later.  Values   */
/*     as listed below.                                                      */
/*   disposition                                                             */
/*     value of disposition from the initiate request (values listed         */
/*     under INSTALL_REQ above).                                             */
/*   object_class                                                            */
/*     data object class of command file. Values are from Appendix E of the  */
/*     SNA/FS Reference manual.                                              */
/*   local_rc                                                                */
/*     return code from DACA. Values are from the HLD for DACA.              */
/*   error_file                                                              */
/*     Global file name of a file to be reported on in the event of an       */
/*     error.                                                                */
/*                                                                           */
/*****************************************************************************/
typedef struct initiate_rpt
{
  DC_STATUS     result;
  DC_USHORT     job_state;
  DC_USHORT     disposition;
  DC_ULONG      object_class;
  DC_ULONG      local_rc;
  DC_GLOB       error_file;
} INITIATE_RPT;

/*****************************************************************************/
/* Values for job_state field                                                */
/*****************************************************************************/
#define     JOB_ACCEPTED        0x03        /* will attempt job              */
#define     JOB_ENDED           0x07        /* job has been initiated        */


/*****************************************************************************/
/* Structure: TRANSFER_RPT                                                   */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is passed to RB_SCHED_REQUEST to report on a Send or     */
/*   Retrieve distribution request issued by a D&CC Agent.                   */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of the request. Values listed under DC_STATUS above).          */
/*   abort                                                                   */
/*     specifies whether the SNA/DS node aborted the delete request. Values  */
/*     listed below (under DELETE_RPT).                                      */
/*   backout                                                                 */
/*     specifies whether the SNA/DS node backed out the delete request.      */
/*     Values listed below (under DELETE_RPT).                               */
/*                                                                           */
/*****************************************************************************/
typedef struct transfer_rpt
{
  DC_STATUS     result;
  DC_USHORT     abort;
  DC_USHORT     backout;
} TRANSFER_RPT;


/*****************************************************************************/
/* Structure: DISTRIB_RPT                                                    */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is passed to RB_SCHED_REQUEST to report on a D&CC        */
/*   request issued by a D&CC Agent that has failed in SNA/DS.               */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of the request. Values listed under DC_STATUS above).          */
/*                                                                           */
/*****************************************************************************/
typedef struct distrib_rpt
{
  DC_STATUS     result;
} DISTRIB_RPT;


/*****************************************************************************/
/* Structure: GEN_FS_RPT                                                     */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used as the basic format of the DELETE_RPT, STORE_RPT */
/*   and FETCH_RPT structures.                                               */
/*                                                                           */
/*   This structure is used by DACA to report on the progress of a           */
/*   DELETE_REQ distribution request.                                        */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of the request. Values listed under DC_STATUS above).          */
/*   abort                                                                   */
/*     specifies whether DACA aborted the delete request. Values listed      */
/*     below                                                                 */
/*   backout                                                                 */
/*     specifies whether DACA backed out the delete request. Values listed   */
/*     below.                                                                */
/*   file_rpt                                                                */
/*     specifies which of the global names in the DC_NAMES structure in the  */
/*     entry header info is associated with the SNA sense code. Values       */
/*     listed below.                                                         */
/*   pad1                                                                    */
/*     added to pad structure to a 4 byte boundary                           */
/*                                                                           */
/*****************************************************************************/
typedef struct gen_fs_rpt
{
  DC_STATUS     result;
  DC_USHORT     abort;
  DC_USHORT     backout;
  DC_USHORT     file_rpt;
  DC_CHAR       pad1[2];
} GEN_FS_RPT;

/*****************************************************************************/
/* Values for abort field                                                    */
/*****************************************************************************/
#define AB_ABORTED          1       /* File operation was aborted            */
#define AB_NOT_ABORTED      2       /* File operation was not aborted        */

/*****************************************************************************/
/* Values for backout field                                                  */
/*****************************************************************************/
#define BA_BACKED_OUT       1       /* File operation was backed out         */
#define BA_NOT_BACKED       2       /* File operation was not successfully   */
                                    /* backed out (or was not intended to be */
                                    /* backed out)                           */

/*****************************************************************************/
/* Values for file reported field                                            */
/*****************************************************************************/
#define FR_NONE             1       /* No file name reported                 */
#define FR_DELETED          2       /* Report the 'deleted/to be deleted'    */
                                    /* file name                             */
#define FR_STORED           3       /* Report the 'stored/to be stored'      */
                                    /* file name                             */
#define FR_FETCHED          4       /* Report the 'fetch/to be fetched'      */
                                    /* file name                             */


/*****************************************************************************/
/* Structure: DELETE_RPT                                                     */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by DACA to report                                */
/*   on the progress of a DELETE_REQ distribution request.                   */
/*                                                                           */
/*   For a description of the fields see the GEN_FS_RPT structure above.     */
/*                                                                           */
/*****************************************************************************/
typedef GEN_FS_RPT DELETE_RPT;


/*****************************************************************************/
/* Structure: STORE_RPT                                                      */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by DACA to report                                */
/*   on the progress of a STORE_REQ distribution request.                    */
/*                                                                           */
/*   For a description of the fields see the GEN_FS_RPT structure above.     */
/*                                                                           */
/*****************************************************************************/
typedef GEN_FS_RPT STORE_RPT;


/*****************************************************************************/
/* Structure: FETCH_RPT                                                      */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by DACA to report                                */
/*   on the progress of a FETCH_REQ distribution request.                    */
/*                                                                           */
/* Fields:                                                                   */
/*   gen_rpt                                                                 */
/*     Result of the request. See GEN_FS_RPT structure above.                */
/*   fetch_info                                                              */
/*     Information about the request and about the file fetched,             */
/*     including compression instructions, CCSID, and catalog                */
/*     entry.                                                                */
/*     See the FETCH_STORE_REQ structure above.                              */
/*     The ccsid field contains the CCSID of the data file, or               */
/*     0 if the file is not a text file.  This is returned by                */
/*     DACA as the 'discovered' CCSID of the store file (and                 */
/*     therefore the CCSID of the file fetched from the client).             */
/*     Unlike earlier releases, V2R0 does not require the                    */
/*     origin_group field to support sending a file to a group               */
/*     of targets.                                                           */
/*                                                                           */
/*****************************************************************************/
typedef struct fetch_rpt
{
  GEN_FS_RPT      gen_rpt;
  FETCH_STORE_REQ fetch_info;
} FETCH_RPT;


/*****************************************************************************/
/* Structure: SND_INSTALL_RPT                                                */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by D&CC Agents to report                         */
/*   on the progress of a SND_INSTALL_REQ change management request.         */
/*                                                                           */
/* Fields:                                                                   */
/*   store                                                                   */
/*     reports on the store associated with the original request. See        */
/*     STORE_RPT above for definition of fields and values.                  */
/*   install                                                                 */
/*     reports on the install process itself. See INSTALL_RPT                */
/*     above for definition of fields and values.                            */
/*                                                                           */
/*****************************************************************************/
typedef struct snd_install_rpt
{
  STORE_RPT     store;
  INSTALL_RPT   install;
} SND_INSTALL_RPT;


/*****************************************************************************/
/* Structure: SND_INITIATE_RPT                                               */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by D&CC Agents to report                         */
/*   on the progress of a SND_INITIATE_REQ change management request.        */
/*                                                                           */
/* Fields:                                                                   */
/*   store                                                                   */
/*     reports on the store associated with the original request. See        */
/*     STORE_RPT above for definition of fields and values.                  */
/*   initiate                                                                */
/*     reports on the initiate process itself. See INITIATE_RPT              */
/*     above for definition of fields and values.                            */
/*                                                                           */
/*****************************************************************************/
typedef struct snd_initiate_rpt
{
  STORE_RPT     store;
  INITIATE_RPT  initiate;
} SND_INITIATE_RPT;


/*****************************************************************************/
/* Structure: UNINSTALL_RPT                                                  */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by D&CC Agents to report on the                  */
/*   progress of an UNINSTALL_REQ change management request.                 */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of the request. Values listed under DC_STATUS above).          */
/*   effective                                                               */
/*     Specifies when the changes will be effective. Values listed under     */
/*     INSTALL_RPT above.                                                    */
/*   local_rc                                                                */
/*     return code from DACA. Values are from the HLD for DACA.              */
/*   error_file                                                              */
/*     Global file name of a file to be reported on in the event of an       */
/*     error.                                                                */
/*   object_class                                                            */
/*     data object class of command file. Values are from Appendix E of the  */
/*     SNA/FS Reference manual.                                              */
/*                                                                           */
/*****************************************************************************/
typedef struct uninstall_rpt
{
  DC_STATUS     result;
  DC_USHORT     effective;
  DC_CHAR       pad[2];
  DC_ULONG      local_rc;
  DC_GLOB       error_file;
  DC_ULONG      object_class;
} UNINSTALL_RPT;


/*****************************************************************************/
/* Structure: RET_INV_RPT                                                    */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by D&CC Agents to report on the                  */
/*   progress of a Q_RET_INV_REQ change management request.                  */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of the request. Values listed under DC_STATUS above).          */
/*                                                                           */
/*****************************************************************************/
typedef struct ret_inv_rpt
{
  DC_STATUS     result;
} RET_INV_RPT;


/*****************************************************************************/
/* Structure: REBOOT_COMP_RPT                                                */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by D&CC Agents to report that a reboot has       */
/*   occured.                                                                */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of the request. Values listed under DC_STATUS above).          */
/*                                                                           */
/*****************************************************************************/
typedef struct reboot_comp_rpt
{
  DC_STATUS     result;
} REBOOT_COMP_RPT;


/*****************************************************************************/
/* Structure: CHKCM_RPT                                                      */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by D&CC agent to report that the user            */
/*   exit cx_chkcm was not found                                             */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of the request. Values listed under DC_STATUS above            */
/*                                                                           */
/*****************************************************************************/
typedef struct chkcm_rpt
{
  DC_STATUS     result;
} CHKCM_RPT;


/*****************************************************************************/
/* Structure: UPDCM_RPT                                                      */
/*                                                                           */
/* Overview:                                                                 */
/* To be better defined.                                                     */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of the request. Values listed under DC_STATUS above            */
/*                                                                           */
/*****************************************************************************/
typedef struct updcm_rpt
{
  DC_STATUS     result;
  DC_ULONG      object_class;
  DC_USHORT     force_exec;
  DC_CHAR       action;
  EXT_CM_STATUS cm_status;
  DC_CHAR       pad[3];
} UPDCM_RPT;


/*****************************************************************************/
/* Structure: VAGUE_CM_RPT                                                   */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by NGA Out to report failed change management    */
/*   requests for which the request type is unknown.                         */
/*   This report type occurs only at the Remote Admin Site and only under    */
/*   the following circumstances:                                            */
/*   -  Remote Admin Site sends a change management request (install,        */
/*      remove, accept, uninstall, activate or initiate) to another server.  */
/*   -  NGA Out on the other server cannot process the request because of an */
/*      error (eg a parsing error).  In such cases NGA Out generates a       */
/*      minimal CM report which does not identify the original request type. */
/*   -  The minimal CM report is sent back to the Remote Admin Site.         */
/*   -  NGA Out at the Remote Admin Site translates the report into an RR    */
/*      format request with type Q_VAGUE_CM_RPT.                             */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of the request.  Values listed under DC_STATUS above.          */
/*                                                                           */
/*****************************************************************************/
typedef struct vague_cm_rpt
{
  DC_STATUS     result;
} VAGUE_CM_RPT;


/*****************************************************************************/
/* Structure: GEN_RPT                                                        */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used to report on requests which do not have special  */
/*   reporting requirements.                                                 */
/*   Currently this report type is used for the following reports:           */
/*     Q_AUTHORIZE_RPT                                                       */
/*     Q_UNAUTHORIZE_RPT                                                     */
/*     Q_AUTOREG_RPT                                                         */
/*     Q_UFID_RPT                                                            */
/*   This list may be extended to include new report types in future         */
/*   releases.                                                               */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of the request.  Values listed under DC_STATUS above.          */
/*                                                                           */
/*****************************************************************************/
typedef struct gen_rpt
{
  DC_STATUS     result;
} GEN_RPT;


/*****************************************************************************/
/* Structure: OPEN_CONN_WIN_RPT                                              */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by DACA on mobile clients to control the         */
/*   resynchronisation of databases.                                         */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of request. Will be ST_OK.                                     */
/*   req_type                                                                */
/*     Type of the open request this report corresponds to.                  */
/*                                                                           */
/*****************************************************************************/
typedef struct open_conn_win_rpt
{
  DC_STATUS     result;
  DC_USHORT     req_type;
} OPEN_CONN_WIN_RPT;


/*****************************************************************************/
/* Structure: CLOSE_CONN_WIN_RPT                                             */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used by DACA on mobile clients to control the         */
/*   resynchronisation of databases.                                         */
/*                                                                           */
/* Fields:                                                                   */
/*   result                                                                  */
/*     Result of request. Will be ST_OK.                                     */
/*                                                                           */
/*****************************************************************************/
typedef struct close_conn_win_rpt
{
  DC_STATUS     result;
} CLOSE_CONN_WIN_RPT;


/*****************************************************************************/
/* Vector definitions                                                        */
/*                                                                           */
/* The vectors that may be encountered at the end of the scheduler queue     */
/* entry are defined below. The definitions include                          */
/*                                                                           */
/* -   the #define for the vector type                                       */
/* -   the structure of the type-specific data (or reference)                */
/* -   the length of the type-specific data.                                 */
/*                                                                           */
/* Vector data may be in native or line format. The data format is specified */
/* for each vector below.                                                    */
/*                                                                           */
/* Note that the vectors are byte aligned and hence may not be correctly     */
/* aligned for the structures they contain.  If you need to access the d     */
/* datain a vector you must copy it to a local buffer with the correct       */
/* alignment first.                                                          */
/*                                                                           */
/*****************************************************************************/


/*****************************************************************************/
/* Vector: V_CORRELATOR                                                      */
/*                                                                           */
/* Structure: SNA/DS Agent Unit-of-work Correlator (refer to SNA Formats     */
/*                                                      manual)              */
/*                                                                           */
/* Overview                                                                  */
/*   This is the Agent Unit-of-work Correlator that accompanies each D&CC    */
/*   request, and which is sent back to the SNA/DS 'report-to' destination   */
/*   on the report.  It is present on all Requests except SEND_REQ and       */
/*   RETRIEVE_REQ, and may be present on all reports, except TRANSFER_RPT    */
/*   and DISTRIB_RPT.                                                        */
/*                                                                           */
/*   The data is in line format.                                             */
/*                                                                           */
/* Length: Variable                                                          */
/*                                                                           */
/*****************************************************************************/
#define     V_CORRELATOR        0x0000


/*****************************************************************************/
/* Vector: V_CONDITION_RPT                                                   */
/*                                                                           */
/* Structure: SNA Condition Report (refer to SNA Formats manual)             */
/*                                                                           */
/* Overview                                                                  */
/*   This is an exception report. It always accompanies a Distribution       */
/*   Report and may accompany a Transfer Report. No other report / request   */
/*   carries this vector.                                                    */
/*                                                                           */
/*   The data is in line format.                                             */
/*                                                                           */
/* Length: Variable                                                          */
/*                                                                           */
/*****************************************************************************/
#define     V_CONDITION_RPT     0x0001


/*****************************************************************************/
/* Vector: V_ADDITIONAL_SENSE                                                */
/*                                                                           */
/* Structure: Varies                                                         */
/*                                                                           */
/* Overview                                                                  */
/*   This vector is used by the Scheduler to pass supporting sense data as   */
/*   part of a Fetch, Store, Delete, Send Install or Send Initiate Report to */
/*   NGA for exception reporting.  The structure of the data depends on the  */
/*   SNA/FS sense code passed (refer to SNA/FS Report Codes in Appendix C of */
/*   the SNA/FS Reference manual).                                           */
/*                                                                           */
/*   The data is in line format.                                             */
/*                                                                           */
/* Length: Variable                                                          */
/*                                                                           */
/*****************************************************************************/
#define     V_ADDITIONAL_SENSE  0x0002


/*****************************************************************************/
/* Vector: V_REPORT_INFO                                                     */
/*                                                                           */
/* Overview                                                                  */
/*   This is the information that NGA requires to route reports for a        */
/*   request to the appropriate SNA/DS node.  It is present on all Requests  */
/*   except SEND_REQ and RETRIEVE_REQ, and may be present on all reports,    */
/*   except TRANSFER_RPT.                                                    */
/*                                                                           */
/*   The data is in native format.                                           */
/*                                                                           */
/* Structure: V_REPORT_STRUC                                                 */
/*   Fields:                                                                 */
/*     report_DSU                                                            */
/*       the DSU to send reports to.                                         */
/*     report_agent                                                          */
/*       the agent to send reports to.                                       */
/*     report_user                                                           */
/*       the user name to send reports to. This may be set to nulls if there */
/*       is no report user name for the request.                             */
/*     rpt_service_parms                                                     */
/*       the service parameters for use on the report. Values defined in the */
/*       HLD for the Router.                                                 */
/*     requester_DSU                                                         */
/*       the DSU to send a Fetched file to                                   */
/*     requester_agent                                                       */
/*       the agent to send a Fetched file to                                 */
/*     requester_user                                                        */
/*       the user name to send a Fetched file to. This is may be set to      */
/*       nulls if there was no origin user name on the Fetch request.        */
/*     req_service_parms                                                     */
/*       the service parameters for use when sending the file. Values        */
/*       defined in the HLD for the Router.                                  */
/*                                                                           */
/*   The following fields are only used in Fetch Requests / Reports. They    */
/*   are unused for all other requests / reports                             */
/*                                                                           */
/*     src_server_parm                                                       */
/*       the server parameter passed to SS when sending files.Values defined */
/*       in the HLD for the File Server.                                     */
/*     tgt_server_parm                                                       */
/*       the target parameter passed to SS when sending files. Values        */
/*       defined in the HLD for the File Server.                             */
/*     src_agent_ins                                                         */
/*       the agent instructions for action on the server. Values defined in  */
/*       Chapter 17 of the SNA Formats manual.                               */
/*     tgt_agent_ins                                                         */
/*       the agent instructions for action on the ultimate target. Values    */
/*       defined in Chapter 17 of the SNA Formats manual.                    */
/*                                                                           */
/*   The following field is present on all requests/report which have passd  */
/*   through NGA OUT                                                         */
/*                                                                           */
/*     destination_DSU                                                       */
/*       the DSU this request is targeted at                                 */
/*                                                                           */
/* Length: sizeof(V_REPORT_STRUC)                                            */
/*                                                                           */
/*****************************************************************************/
#define     V_REPORT_INFO       0x0003

typedef struct v_report_struc
{
  DC_DSU_NAME       report_DSU;
  DC_TP_NAME        report_agent;
  DC_USER_NAME      report_user;
  DC_SERVICE_PARMS  rpt_service_parms;
  DC_DSU_NAME       requester_DSU;
  DC_TP_NAME        requester_agent;
  DC_USER_NAME      requester_user;
  DC_SERVICE_PARMS  req_service_parms;
  DC_SSPARMS        src_server_parm;
  DC_SSPARMS        tgt_server_parm;
  DC_CHAR           src_agent_ins;
  DC_CHAR           tgt_agent_ins;
  DC_CHAR           pad[2];
  DC_DSU_NAME       destination_DSU;
} V_REPORT_STRUC;


/*****************************************************************************/
/* Vector: V_SECOND_INSTALL                                                  */
/*                                                                           */
/* Overview                                                                  */
/*   This vector is used by the Scheduler to pass to NGA the results of a    */
/*   secondary installation which may have taken place due to a Remove       */
/*   Request.  It is only passed on a Remove Report and is always            */
/*   accompanied by a V_SECOND_NAMES vector (see below).                     */
/*                                                                           */
/*   The data is in native format.                                           */
/*                                                                           */
/* Structure: V_SECOND_STRUC                                                 */
/*   Fields:                                                                 */
/*     status                                                                */
/*       status of the secondary installation. Values listed above (under    */
/*       'ar_effective' values for INSTALL_RPT - AR_NA is not allowed for    */
/*       this field).                                                        */
/*     activation_use                                                        */
/*       reports on the type of activation which will activate these changes.*/
/*       Values listed above (under 'act_status' values for INSTALL_RPT -    */
/*       ACT_NOT_INST is not allowed for this field).                        */
/*                                                                           */
/* Length: sizeof(V_SECOND_STRUC)                                            */
/*                                                                           */
/*****************************************************************************/
#define     V_SECOND_INSTALL    0x0005

typedef struct v_second_struc
{
  DC_USHORT status;
  DC_USHORT activation_use;
} V_SECOND_STRUC;


/*****************************************************************************/
/* Vector: V_SECOND_NAMES                                                    */
/*                                                                           */
/* Overview                                                                  */
/*   This vector is used by the Scheduler to pass to NGA the names of files  */
/*   that were installed as a secondary effect of a Remove Request.  It is   */
/*   only passed if the V_SECOND_INSTALL vector is also passed, and          */
/*   therefore is only passed on Remove Report.                              */
/*                                                                           */
/*   The data is in native format.                                           */
/*                                                                           */
/* Structure: DC_GLOB * number of names                                      */
/*                                                                           */
/* Length: sizeof(DC_GLOB) * number of names                                 */
/*                                                                           */
/*****************************************************************************/
#define     V_SECOND_NAMES      0x0006


/*****************************************************************************/
/* Vector: V_BACK_NAMES                                                      */
/*                                                                           */
/* Overview                                                                  */
/*   This vector is used by the Scheduler to pass to NGA the names of files  */
/*   put into a back level state by an Install Request.  It is only passed   */
/*   on an Install Report.                                                   */
/*                                                                           */
/*   The data is in native format.                                           */
/*                                                                           */
/* Structure: DC_GLOB * number of names                                      */
/*                                                                           */
/* Length: sizeof(DC_GLOB) * number of names                                 */
/*                                                                           */
/*****************************************************************************/
#define     V_BACK_NAMES        0x0007


/*****************************************************************************/
/* Vector: V_DELETED_NAMES                                                   */
/*                                                                           */
/* Overview                                                                  */
/*   This vector is used by the Scheduler to pass to NGA the names of files  */
/*   that were deleted as part of an Install, Uninstall or Accept Request.   */
/*   It is only passed on Install, Uninstall and Accept reports.             */
/*                                                                           */
/*   The data is in native format.                                           */
/*                                                                           */
/* Structure: DC_GLOB * number of names                                      */
/*                                                                           */
/* Length: sizeof(DC_GLOB) * number of names                                 */
/*                                                                           */
/*****************************************************************************/
#define     V_DELETED_NAMES     0x0008


/*****************************************************************************/
/* Vector: V_SSN                                                             */
/*                                                                           */
/* Overview                                                                  */
/*   This vector is used by NGA to pass the SSN through to DACA if this      */
/*   SNA/FS structure is received on a request from the host. It may be      */
/*   present on Store, Fetch, Send&Install or Send&Initiate requests.        */
/*                                                                           */
/*   The data is in line format (since NGA does not interpret the SSN).      */
/*                                                                           */
/* Structure: Bytestream containing System_Specific_Name SNA/FS structure if */
/*            it was specified on a received request.                        */
/*                                                                           */
/* Length: up to 2048 bytes                                                  */
/*                                                                           */
/*****************************************************************************/
#define     V_SSN               0x0009


/*****************************************************************************/
/* Vector: V_TARGET_LIST                                                     */
/*                                                                           */
/* Overview                                                                  */
/*   This vector is used by the UI to pass to RH the list of destinations    */
/*   of a specific Request.                                                  */
/*   The vector can be identified by V_TARGET_LIST if a list of targets      */
/*   follows or by V_DOMAIN_LIST if a list of domains follows.               */
/*   The data is in native format.                                           */
/*                                                                           */
/* Structure: V_TARGET_STRUCT                                                */
/*   Fields:                                                                 */
/*     target_count                                                          */
/*       the target count                                                    */
/*     target_list                                                           */
/*       the list of targets or groups addressed by the request              */
/*                                                                           */
/* Length: 4 + number of targets/groups * sizeof(TARGET_NAME)                */
/*                                                                           */
/*****************************************************************************/
#define    V_TARGET_LIST          0x000A
#define    V_DOMAIN_LIST          0x000B

typedef struct v_target_struct
{
  DC_USHORT   target_count;
  DC_USHORT   pad;
  TARGET_NAME target_list[1];
} V_TARGET_STRUCT;

/*****************************************************************************/
/* Vector: V_ADDRESS_LIST                                                    */
/*                                                                           */
/* Overview                                                                  */
/*   This vector is used by the RH to pass to SCHED the list of remote       */
/*   destinations of a specific Request.                                     */
/*   The data is in native format.                                           */
/*                                                                           */
/* Structure: V_ADDR_STRUCT                                                  */
/*   Fields:                                                                 */
/*     origin                                                                */
/*       the DSU_NAME of the originator of the request                       */
/*       Note that this name is not the name of the domain from              */
/*       which the request has been originated but rather the name of the    */
/*       client machine where the request has been submitted from, so it is  */
/*       NOT, in general, the name of the server (see origin_server instead) */
/*     source                                                                */
/*       the initial source of the file in RGN.REN format this is in fact    */
/*       the same value as the one in QUEUE_ENTRY but in a whole-network     */
/*       valid format, source in QUEUE_ENTRY may change from domain to domain*/
/*     int_source                                                            */
/*       the intermediate source of the file in RGN.REN format               */
/*       This is the same value as the one in QUEUE_ENTRY but in a           */
/*       whole-network valid format, int_source in QUEUE_ENTRY may change    */
/*       from domain to domain. This field is used in intermediate node cases*/
/*       to know where the file has to be Fetched from.                      */
/*     report_to                                                             */
/*       the report-to server name in RGN.REN format                         */
/*       In reports this is the name of the server which the report is to be */
/*       sent to - either the originating server or the report-to focal      */
/*       point depending on the report type.  When a report is first         */
/*       generated this field should be null - RH sets the report-to name    */
/*       when it processes the report and determines where it should be      */
/*       sent.                                                               */
/*       In requests the report_to fields is null.                           */
/*     origin_server                                                         */
/*       the server name in RGN.REN format of the domain where the request   */
/*       has been originally submitted. This field is used for build the     */
/*       request identifier locally for request, report or CANCEL command    */
/*     block_count                                                           */
/*       the number of blocks containing the address list for each addressed */
/*       server. They are in V_ADDR_BLOCK format.                            */
/*                                                                           */
/* Structure: V_ADDR_BLOCK                                                   */
/*   Fields:                                                                 */
/*     server                                                                */
/*       the DSU_NAME of the addressed server                                */
/*     target_count                                                          */
/*       the number of addressed targets within the above mentioned server   */
/*     targets_ren                                                           */
/*       the list of targets ren                                             */
/*                                                                           */
/* NB: The general rule is that in reports the fields in the                 */
/*     V_ADDRESS_LIST vector contain reported-on values rather               */
/*     than values applying to the report.  For example, origin              */
/*     is the originator of the request, not the originator of               */
/*     the report, and the V_ADDR_BLOCK structures contain                   */
/*     the targets of the request not the destination of the                 */
/*     report.                                                               */
/*                                                                           */
/* Length: the maximum length is 32K (defined by V_ADDR_MAXLEN               */
/*         below) or about 4000 targets                                      */
/*         V_ADDR_MAXLEN excludes the 4 byte vector header.                  */
/*         The maximum number of targets depends on the size of              */
/*         the V_ADDR_STRUCT and V_ADDR_BLOCK structures, and                */
/*         on how many blocks are in the vector.  With the current           */
/*         V_ADDR_STRUCT and V_ADDR_BLOCK structures a single                */
/*         block vector can contain up to 4084 targets.                      */
/*                                                                           */
/*****************************************************************************/
#define    V_ADDRESS_LIST     0x000C
#define    V_ADDR_MAXLEN      24560

typedef struct v_addr_struct
{
  DC_DSU_NAME origin;
  DC_DSU_NAME source;
  DC_DSU_NAME int_source;
  DC_DSU_NAME report_to;
  DC_DSU_NAME origin_server;
  DC_USHORT   block_count;
  DC_USHORT   pad;
} V_ADDR_STRUCT;

typedef struct v_addr_block
{
  DC_DSU_NAME server;
  DC_USHORT   target_count;
  DC_USHORT   pad;
  DC_CHAR     targets[1/*..about 4000*/][DVA_REN_LEN];
} V_ADDR_BLOCK;

/*****************************************************************************/
/* REMOTE_DIR moved to fndhdr.h                                              */
/*****************************************************************************/

/*****************************************************************************/
/* Structure: TRG_INFO                                                       */
/*                                                                           */
/* Overview:                                                                 */
/*     This structure is used by Scheduler to pass target name to the        */
/*     sx_export_dir User Exit                                               */
/*                                                                           */
/* Fields:                                                                   */
/*   destination                                                             */
/*     the name of destination for the request                               */
/*****************************************************************************/
typedef struct trg_info
{
  DC_CHAR           destination[DVA_TRGNAME_LEN];
} TRG_INFO;


/*****************************************************************************/
/*  Constant values set in User Exits, sx_export_dir and sx_unexport_dir     */
/*  and tested in Scheduler                                                  */
/*****************************************************************************/
#define EXPORTED           4
#define SH_RDIR_NOT_EXIST  8
#define UNRECOVERABLE      12


/*****************************************************************************/
/* Vector: V_REMOTE_DIR                                                      */
/*                                                                           */
/* Overview                                                                  */
/*      This vector is used by Scheduler to pass the remote directory        */
/*      to the agent DACA in order to get them again after install processing*/
/*      The Scheduler fills in it with the exported directories              */
/*       according to REMOTE_DIR structure                                   */
/*      This vector is used by Scheduler during report processing            */
/*      for unexporting those directories                                    */
/* Structure                                                                 */
/*      Contains up to 16 structures, each representing an exported          */
/*      directory                                                            */
/* Length: sizeof(REMOTE_DIR) * number of remote directories +               */
/*         sizeof(DC_USHORT)                                                 */
/*                                                                           */
/*****************************************************************************/
#define     V_REMOTE_DIR    0x000D

typedef struct v_remote_dir_struct
{
  DC_USHORT   num_remote_dir;
  REMOTE_DIR  remote_dir;
} V_REMOTE_DIR_STRUCT;


/*****************************************************************************/
/* Structure: MSG_INFO                                                       */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure defines the message information came back with report    */
/* Fields:                                                                   */
/*  msg_id                                                                   */
/*    Message identifier (format like FNDnnxxxn)                             */
/*  msg_num                                                                  */
/*    Message number: the number is the internal number associated to the    */
/*    message having name msg_id (for the association see dvacomnu.h file)   */
/*  product_id                                                               */
/*    Product identifier for the product running on the target writing the   */
/*    message                                                                */
/*  sys_level                                                                */
/*    Level of the product_id product installed at target                    */
/*  timestamp                                                                */
/*    Time at witch of the messasge has been written on the message log      */
/*  text                                                                     */
/*    Parameters of the message (the parameters are separated by the         */
/*    DVA_PARMS_SEP character                                                */
/*****************************************************************************/
#define DVA_PARMS_SEP_CHR   '|'
typedef  struct msg_info
{
  DC_CHAR    msg_id[9];
  DC_USHORT  msg_num;
  DC_CHAR    product_id;
  DC_CHAR    sys_level[9];
  DC_CHAR    pad[3];
  SCHED_TIME timestamp;
#define  DVA_MSG_TEXT_LEN       1024
         DC_CHAR     text[DVA_MSG_TEXT_LEN];
}  MSG_INFO;

/*****************************************************************************/
/* Structure: V_REPORT_DATA                                                  */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure defines some information came back into the report       */
/* Fields:                                                                   */
/*  exec_time                                                                */
/*    Time in which the subrequest has been executed at target               */
/*  type                                                                     */
/*    Type of structure within the union                                     */
/*  data                                                                     */
/*    Data specific to the type of the report_data                           */
/*****************************************************************************/
#define     V_MESSAGE_RPT   0x000E

typedef struct v_report_data
{
   DC_USHORT   type;
#define  RPT_MSG_NO_REPORT      0xffff
#define  RPT_MSG_REPORT         0x0001
   union
   {
       MSG_INFO  msg;
   } data;
}  V_REPORT_DATA;

/*****************************************************************************/
/* Vector:  V_SERVER_LIST                                                    */
/*                                                                           */
/* Overview:                                                                 */
/*   This vector is used to report to the UI the list of servers a destribu- */
/*   tion is targeted                                                        */
/*                                                                           */
/* Structure: V_SERVER_STRUCT                                                */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure contains the number of sub-structures SERVER to display  */
/* Fields:                                                                   */
/*  server_count                                                             */
/*    Number of SERVER sub-structure contained                               */
/*  server_list                                                              */
/*    list of SERVER sub-structures                                          */
/*                                                                           */
/* Structure: SERVER                                                         */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure contains the info targeted to each server                */
/* Fields:                                                                   */
/*  target_count                                                             */
/*    Number of targets each server is referring to                          */
/*  target                                                                   */
/*    Server long name                                                       */
/*****************************************************************************/

#define    V_SERVER_LIST      0x000F

typedef struct server
{
  DC_USHORT   target_count;
  DC_USHORT   pad;
  DC_CHAR     target[DVA_TRGNAME_LEN];
} SERVER;

typedef struct v_server_struct
{
  DC_USHORT   server_count;
  DC_USHORT   pad;
  SERVER      server_list[1];
} V_SERVER_STRUCT;

/*****************************************************************************/
/* Vector:  V_V2R0_INFO                                                      */
/*                                                                           */
/* Overview:                                                                 */
/*   This vector is used to store the new info contained in the V2R0 queue   */
/*   entry during the exchange of request blocks between a V2R0 server and   */
/*   a R1.1 agent.                                                           */
/*                                                                           */
/* Structure: V_V2R0_INFO_STRU                                               */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure contains the new V2R0 queue entry fields                 */
/* Fields:                                                                   */
/*   req_id                                                                  */
/*     specifies the request identifier.                                     */
/*   subreq_id                                                               */
/*     specifies the sub-request identifier.                                 */
/*     It is used to identify a sub-request generated by a plan whose        */
/*     request identifier is "req_id".                                       */
/*     If req_id identifies a single request, subreq-id is filled with       */
/*     zeroes                                                                */
/*                                                                           */
/*   exec_time_wnd                                                           */
/*     specifies the time window the request has to be executed at           */
/*     destination.                                                          */
/*   appl_id                                                                 */
/*     is the identifier of the application that issued the request.         */
/*   rec_week_sched                                                          */
/*     specifies the week days the URH generates a new recursion.            */
/*   rec_type                                                                */
/*     specifies the recursion type - value listed above (see SCHEDULE_INFO) */
/*   rec_interval                                                            */
/*     specifies the recursion interval.                                     */
/*   rec_week_sched                                                          */
/*     specifies the week days the URH generates a new recursion.            */
/*   rec_expir_time                                                          */
/*     specifies the date and time when the recursive request is stopped.    */
/*   rec_month_sched                                                         */
/*     specifies the month days the request is to take place                 */
/*   term procedure                                                          */
/*     Procedure name to be executed when the request is completed           */
/*   term target                                                             */
/*     Name of the target where the term procedure must be executed          */
/*   flags                                                                   */
/*     They indicate the initial status of the Request. The values are:      */
/*          REQ_FLAG_RELEASED    released state (default)                    */
/*          REQ_FLAG_HELD        hold state                                  */
/*   recgen_max_severity                                                     */
/*     It is the max severity of a recursive request according to a new      */
/*     recursion can be generated                                            */
/*   recgen_continue                                                         */
/*     TRUE  -  The recursion must continue if the previous instance has     */
/*               not been executed                                           */
/*     FALSE -  The recursion must be stopped if the previous instance has   */
/*               not been executed                                           */
/*   category                                                                */
/*     D&CC queue category - values listed below                             */
/*   rrstatus                                                                */
/*     This is an internal status used by the RS library.                    */
/*   dest_conn                                                               */
/*     This is the name of the connection to be used to send the request.    */
/*     If dest_conn is set, the vector V_ADDRESS_LIST specifies the          */
/*     destination list; in this case final_dest is set to zeroes.           */
/*   history_reset                                                           */
/*     This is an internal status used by the RS library.                    */
/*****************************************************************************/

#define    V_V2R0_INFO        0x0010

typedef struct v_v2r0_info_struct
{
  REQUEST_ID        req_id;
  DC_CHAR           subreq_id[DVA_REQID_LEN];
  TIME_WINDOW       exec_time_wnd;
  DC_CHAR           appl_id[DVA_APPLID_LEN];
  DC_CHAR           rec_week_sched;
  DC_USHORT         rec_type;
  TIME_INTERVAL     rec_interval;
  DC_ULONG          rec_month_sched;
  SCHED_TIME        rec_expir_time;
  DC_GLOB           term_procedure;
  TARGET_NAME       term_target;
  DC_ULONG          flags;
  DC_USHORT         recgen_max_severity;
  DC_USHORT         recgen_continue;
  DC_USHORT         category;
  DC_USHORT         rsstatus;
  DC_CHAR           dest_conn[DVA_CONN_NM_LEN];
  DC_USHORT         history_reset;
  DC_CHAR           int_source[DVA_TRGNAME_LEN];
  DC_SHORT          hop_count;
  DC_USHORT         original_reqid;
  DC_UFID           data_ufid;
  DC_UFID           int_source_ufid;
  DC_DATA_NAME      int_source_file;
  DC_USHORT         except_action;
  DC_USHORT         fetch_ccsid;
  DC_ULONG          local_file_offset;
  DC_ULONG          remote_file_offset;
} V_V2R0_INFO_STRU;



/*****************************************************************************/
/* Vector: V_AUTOREG_VECTOR                                                  */
/*                                                                           */
/* Overview                                                                  */
/*   This vector is used by the RBH to pass to RH the target configuration   */
/*   information for auto registration.                                      */
/*                                                                           */
/* Structure: V_AUTOREG_STRU                                                 */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure contains the type of command to do on the server for     */
/*   the auto registration, the type of structure sent with the vector and   */
/*   the releated information.                                               */
/*                                                                           */
/* Fields:                                                                   */
/*   see the OPERATION_DEF structure.                                        */
/*                                                                           */
/*****************************************************************************/
#define    V_AUTOREG_VECTOR       0x0011

typedef  OPERATION_DEF  V_AUTOREG_STRU;

/*****************************************************************************/
/* Define the type of structure to be passed with the queue entry            */
/*****************************************************************************/
#define    S_TARGET_CONFIG        0x0001
#define    S_TARGET_PARMS         0x0002
#define    S_TARGET_HW            0x0003

/*****************************************************************************/
/* Define the type of operation to be passed with the queue entry            */
/*****************************************************************************/
#define    CMD_AUTOREG_ADD        0x0001
#define    CMD_AUTOREG_UPD        0x0002
#define    CMD_AUTOREG_DEL        0x0004


/*****************************************************************************/
/* Vector: V_LOC_ADDR_LIST                                                   */
/*                                                                           */
/* Overview                                                                  */
/*   This vector is used by UI/RB/VL/RH to schedule a request to a number    */
/*   of destination higher than possible with V_TARGET_LIST vector.          */
/*   The data is in native format.                                           */
/*   The structure is similar to a V_ADDRESS_LIST vector but they are kept   */
/*   separate to avoid getting confused about whether a request was locally  */
/*   or remotely submitted, and because some of the fields in the former     */
/*   structure are not needed when submitting a request.                     */
/*                                                                           */
/* Structure: V_LOC_ADDR_STRUCT                                              */
/*   Fields:                                                                 */
/*     block_count                                                           */
/*       the number of blocks containing the address list for each addressed */
/*       server. They are in V_LOC_ADDR_BLOCK format.                        */
/*                                                                           */
/* Structure: V_LOC_ADDR_BLOCK                                               */
/*   Fields:                                                                 */
/*     server                                                                */
/*       the DSU_NAME of the addressed server                                */
/*     target_count                                                          */
/*       the number of addressed targets within the above mentioned server   */
/*     targets_ren                                                           */
/*       the list of targets ren                                             */
/*                                                                           */
/*                                                                           */
/* Length: the maximum length is 58K (defined by V_LOC_ADDR_MAXLEN           */
/*         below to keep queue length below 64K) or about 7400 targets.      */
/*         V_LOC_ADDR_MAXLEN excludes the 4 byte vector header.              */
/*         The maximum number of targets depends on the size of              */
/*         the V_LOC_ADDR_STRUCT and V_LOC_ADDR_BLOCK structures, and        */
/*         on how many blocks are in the vector.  With the current           */
/*         V_LOC_ADDR_STRUCT and V_LOC_ADDR_BLOCK structures a single        */
/*         block vector can contain up to 7421 targets.                      */
/*                                                                           */
/*****************************************************************************/
#define    V_LOC_ADDR_LIST     0x0012
#define    V_LOC_ADDR_MAXLEN   (58*1024)

typedef struct v_loc_addr_struct
{
  DC_ULONG    block_count;
} V_LOC_ADDR_STRUCT;

typedef struct v_loc_addr_block
{
  DC_DSU_NAME server;
  DC_ULONG    target_count;
  DC_CHAR     targets[1/*...about 7400*/][DVA_REN_LEN];
} V_LOC_ADDR_BLOCK;

/*****************************************************************************/
/* Structure: V_INST_DRV                                                     */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure defines new information for shared object management     */
/* Fields:                                                                   */
/*  driver mode                                                              */
/*    type of behaviour for the request if the condition -c is encountered   */
/*  driver condition                                                         */
/*    Type of condition for shared objects management                        */
/*****************************************************************************/
#define     V_INST_DRV            0x0013

typedef struct v_inst_drv_struc
{
   DC_USHORT   driver_mode;
   DC_USHORT   driver_condition;
}  V_INST_DRV_STRU;

/*****************************************************************************/
/* Values for driver mode field                                              */
/*****************************************************************************/
#define DM_SUCC        0x10     /* req successful even if -c parm verified   */
#define DM_STOP        0x20     /* stop if condition in -c parm verified     */
#define DM_WARN        0x30     /* warn if condition in -c parm verified     */

/*****************************************************************************/
/* Values for driver condition                                               */
/*****************************************************************************/
#define CD_UPLVL       0x10     /* avoid uplevel of files on the target      */
#define CD_BCKLVL      0x20     /* avoid backlevel of files on the target    */
#define CD_EXST        0x30     /* avoid copying of files if already existent*/
/*****************************************************************************/
/* Values for checking attributes on the target                              */
/*****************************************************************************/
#define CD_DIFF        0x40     /* install only if the file is different from*/
                                /* the one already existent on target        */
#define CD_DIFF_CRC    0x50     /* avoid copying of files if CRC is the same */

/*****************************************************************************/
/* Vector: V_LAST_VECTOR                                                     */
/*                                                                           */
/* Overview                                                                  */
/*   This vector signals the end of the vector list.                         */
/*                                                                           */
/* Structure: none                                                           */
/*                                                                           */
/* Length: 0                                                                 */
/*                                                                           */
/*****************************************************************************/
#define     V_LAST_VECTOR        0xFFFF


typedef union generic_rr
{
   INSTALL_REQ         install_req;
   UNINSTALL_REQ       uninstall_req;
   REMOVE_REQ          remove_req;
   ACCEPT_REQ          accept_req;
   ACTIVATE_REQ        activate_req;
   INITIATE_REQ        initiate_req;
   DELETE_REQ          delete_req;
   SND_INSTALL_REQ     sinstall_req;
   SND_INITIATE_REQ    sinitiate_req;
   STORE_REQ           store_req;
   FETCH_REQ           fetch_req;
   CANCEL_REQ          cancel_req;
   HOLD_REL_REQ        hold_req;
   HOLD_REL_REQ        release_req;
   RESCHEDULE_REQ      reschedule_req;
   RESET_REQ           reset_req;
   EXECPLAN_REQ        execplan_req;
   UPDCM_REQ           updcm_req;
   OPEN_CONN_WIN_REQ   openconn_req;
   CLOSE_CONN_WIN_REQ  closeconn_req;
   /* no specifc structure required for AUTHORIZE request                    */
   /* no specifc structure required for UNAUTHORIZE request                  */
   /* no specifc structure required for RET_INV request                      */
   /* no specifc structure required for REBOOT_COMP request                  */
   /* no specifc structure required for CHKCM request                        */
   /* no specifc structure required for CLOSE_CONN_WIN request               */

   INSTALL_RPT         install_rpt;
   UNINSTALL_RPT       uninstall_rpt;
   REMOVE_RPT          remove_rpt;
   ACCEPT_RPT          accept_rpt;
   ACTIVATE_RPT        activate_rpt;
   INITIATE_RPT        initiate_rpt;
   TRANSFER_RPT        transfer_rpt;
   DISTRIB_RPT         distrib_rpt;
   DELETE_RPT          delete_rpt;
   SND_INSTALL_RPT     sinstall_rpt;
   SND_INITIATE_RPT    sinitiate_rpt;
   STORE_RPT           store_rpt;
   FETCH_RPT           fetch_rpt;
   RET_INV_RPT         ret_inv_rpt;
   REBOOT_COMP_RPT     reboot_comp_rpt;
   CHKCM_RPT           chkcm_rpt;
   UPDCM_RPT           updcm_rpt;
   VAGUE_CM_RPT        vague_cm_rpt;
   OPEN_CONN_WIN_RPT   openconn_rpt;
   CLOSE_CONN_WIN_RPT  closeconn_rpt;
   DC_STATUS           bad_req_rpt;
   GEN_RPT             gen_rpt;
}  GENERIC_RR;


/*****************************************************************************/
/* Structure: GENERIC_REQ                                                    */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure contains a union of all possible asynch requests         */
/*                                                                           */
/* Fields:                                                                   */
/*   file                                                                    */
/*     global name(s) to be fetched/stored/deleted with this request/report  */
/*   exec_time_wnd                                                           */
/*     execution time window.                                                */
/*     This is considered by SH only for local targets. SH will transfer     */
/*     immediately this information to remote servers via STS.               */
/*   exec_time                                                               */
/*     time at which request was executed. This is part of the report.       */
/*   flags                                                                   */
/*     RR flags. These are set to NULL (by the UI and NGA Out) when the      */
/*     request is created and set or reset throughout the lifetime of the    */
/*     request. Values are listed below                                      */
/*   type                                                                    */
/*     D&CC request type - values listed below                               */
/*   action                                                                  */
/*     one of either:                                                        */
/*       FORCE_REQ  - dont carry out any validation of request before        */
/*                        scheduling it                                      */
/*       VALID_REQ  - perform Scheduler validation of request before         */
/*                        scheduling it                                      */
/*   data                                                                    */
/*     Data specific to this D&CC type                                       */
/*   source                                                                  */
/*     this is the owner of the file for a send/retrieve request             */
/*****************************************************************************/
typedef struct generic_req
{
   DC_NAMES       file;
   TIME_WINDOW    exec_time_wnd;
   SCHED_TIME     exec_time;
   DC_ULONG       flags;
   DC_USHORT      type;
#define VALID_REQ         0
#define FORCE_REQ         1
   DC_USHORT      action;
   GENERIC_RR     data;
   TARGET_NAME    source;
} GENERIC_REQ;


/*****************************************************************************/
/* Structure: QUEUE_ENTRY                                                    */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure contains an entry from the scheduler queue.              */
/*   The UI sets only V_TARGET_LIST and "source", RH sets "destination",     */
/*   "final_dest" and "source" when the destination is local or "dest_conn"  */
/*   with V_ADDRESS_LIST when the destination is remote.                     */
/*                                                                           */
/* Fields:                                                                   */
/*   q_status                                                                */
/*     This identifies the queue entry format (TC_SECURE_LIST or             */
/*     QUEUE_ENTRY) and which NG component it is to be processed by.         */
/*     This must be the first member in QUEUE_ENTRY (the same as             */
/*     TC_SECURE_LIST in dvang.h).                                           */
/*   ng_space                                                                */
/*     Common work space for TC, NGA In, NGA Out and Scheduler.              */
/*     This must be the second member in QUEUE_ENTRY (the same as            */
/*     TC_SECURE_LIST in dvang.h).                                           */
/*   req_id                                                                  */
/*     specifies the request identifier.                                     */
/*   subreq_id                                                               */
/*     specifies the sub-request identifier.                                 */
/*     It is used to identify a sub-request generated by a plan whose        */
/*     request identifier is "req_id".                                       */
/*     If req_id identifies a single request, subreq-id is filled with       */
/*     zeroes                                                                */
/*   sched_info                                                              */
/*     this structure contains all scheduling parameters.                    */
/*   seq_no                                                                  */
/*     number allocated by the UI to correlate reports with the original     */
/*     request                                                               */
/*   request_no                                                              */
/*     number allocated by the scheduler so that the schedule list can be    */
/*     created in the correct order at start up                              */
/*   submit_time                                                             */
/*     time request was submitted                                            */
/*     WARNING!!! this field was moved from here to SCHEDULE_INFO.           */
/*   sched_time                                                              */
/*     scheduled time of request                                             */
/*     WARNING!!! this field was moved from here to SCHEDULE_INFO.           */
/*   exec_time                                                               */
/*     time at which request was executed                                    */
/*   priority_request                                                        */
/*     TRUE  - this request has been scheduled as a priority request         */
/*     FALSE - this request has not been scheduled as a priority request     */
/*     NOT USED in release 1.0 - added for release 1.1                       */
/*     WARNING!!! this field was moved from here to SCHEDULE_INFO.           */
/*   status                                                                  */
/*     Status of D&CC request/response - values listed below. These values   */
/*     are used by the request Handler and the Scheduler                     */
/*     to checkpoint request / report processing.                            */
/*     When RH put a request (or report) on the                              */
/*     Scheduler Input Queue, THIS FIELD MUST BE INITIALISED TO ST_WAIT.     */
/*   rsstatus                                                                */
/*     This is an internal status used by the RS library. Values listed      */
/*     below                                                                 */
/*   unsolicited                                                             */
/*     TRUE - this report is unsolicited - i.e. it is in response to an      */
/*     Inventory Discovery request.  FALSE - this report is solicited, i.e.  */
/*     it is a direct response to a request.  This field is ignored on a     */
/*     request.                                                              */
/*     In R. 2 another meaning was added to this flag:                       */
/*        CM_INV_UNSOLICITED unsolicited report coming from inv req          */
/*        CM_CHKCM_UNSOLICITED unsolicited report coming from chkcm req      */
/*                                                                           */
/*     Mobile clients added a third:                                         */
/*        CM_MOBC_UNSOLICITED unsolicited report (other than inventory       */
/*        discovery/verify cm) coming from a mobile client.                  */
/*   local_origin                                                            */
/*     Origin flag for request/report. This flag is TRUE if this request     */
/*     (or the request for which this is a report) was initiated by the UI   */
/*     on the local system OR this is a report sent to the local system for  */
/*     which the local system did not issue a request (an 'Unsolicited       */
/*     Report'). In this case the destination list is in V_TARGET_LIST       */
/*     format.                                                               */
/*     The flag is FALSE if this request (or the request for which this is a */
/*     report) was initiated by a remote node. In this case the destination  */
/*     list is in  V_ADDRESS_LIST.                                           */
/*                                                                           */
/*   category                                                                */
/*     D&CC queue category - values listed below                             */
/*   type                                                                    */
/*     D&CC request/response type - values listed below                      */
/*   flags                                                                   */
/*     RR flags. These are set to NULL (by the UI and NGA Out) when the      */
/*     request is created and set or reset throughout the lifetime of the    */
/*     request. Values are listed below                                      */
/*   originator                                                              */
/*     This is the name of the locally configured Target that issued this    */
/*     request (or the request for which this is the report).                */
/*   destination                                                             */
/*     This is the name of the locally configured Target to which this       */
/*     request (or the request for which this is the report) is to be sent.  */
/*     This is used only for local targets.                                  */
/*   final_dest                                                              */
/*     This is the name of the locally configured Target which is the final  */
/*     destination of this request (as opposed to destination which is the   */
/*     next target which must process the request).                          */
/*     If final_dest is set, then dest_conn is set to zeroes.                */
/*   dest_conn                                                               */
/*     This is the name of the connection to be used to send the request.    */
/*     If dest_conn is set, the vector V_ADDRESS_LIST specifies the          */
/*     destination list; in this case final_dest is set to zeroes.           */
/*   file                                                                    */
/*     global name(s) to be fetched/stored/deleted with this request/report  */
/*   source                                                                  */
/*     Local or remote node from which this request came (and to which       */
/*     reports - in particular, Fetch reports - go to).                      */
/*   int_source                                                              */
/*       Same as source field for intermediate node support. This is the     */
/*       of the machine that actually keeps the file, which may differ for   */
/*       the original source of the file.                                    */
/*   group                                                                   */
/*     This is the local group to which this request is to be routed.        */
/*     WARNING: This fileld has been removed because V_TARGET_LIST handles   */
/*     both targets and groups.                                              */
/*   superuser                                                               */
/*     Flag if user issuing request has ability to authorize the target f    */
/*     for a file that is to be distributed to it.                           */
/*     WARNING!!! this field was moved from here to SCHEDULE_INFO.           */
/*                                                                           */
/*   The structure needs to be 4-byte aligned here - currently no pad needed */
/*                                                                           */
/*   type_data                                                               */
/*     Data specific to this D&CC type                                       */
/*   hop_count                                                               */
/*     Hop count, decremented when the QUEUE_ENTRY is sent                   */
/*     from one server to another, and used to prevent                       */
/*     perpetual circulation in the event of a routing loop.                 */
/*     This should be set to zero when a newly-generated request             */
/*     or report is passed to RH.                                            */
/*   original_reqid                                                          */
/*     Set to TRUE when the request is built from the origin RHDB record and */
/*     used as follow to correlate different UOW with the same SNA correlator*/
/*     when the reqeust travels a SNA/DS connection where the information    */
/*     about the request identifier is lost.                                 */
/*      When enqueueing request to remote connection:                        */
/*        - on a SNA/DS connection, NG will set encode only the SNA          */
/*          correlator                                                       */
/*        - on a STS connection the reqeust identifier is sent as it is      */
/*      Receiving request/report                                             */
/*        - from a SNA/DS connection, NG will set this field to FALSE        */
/*        - from a STS connection, it is routed to RH as it is               */
/*          Note taht in this case too the field may be found to FALSE if    */
/*          the reqeust/report traversed a SNA/DS connection during its      */
/*          path to "this" domain                                            */
/*     RH, when the field is FALSE, will generate the request identifier from*/
/*     the SNA correlator (using a new DAS routine) or will use the one      */
/*     already registered (which means that this domain originated the req   */
/*     or that the req already traversed this domain)                        */
/*                                                                           */
/*   rc_cmd                                                                  */
/*     Return code of a data base update for a command. It is used for       */
/*     recovery pouposes ONLY BY REQUEST HANDLER COMPONENT                   */
/*                                                                           */
/*   disconnected_request                                                    */
/*     This field is a bit mask indicating whether the request is            */
/*     disconnected, and if so, held                                         */
/*     This field only applies to requests for mobile clients                */
/*                                                                           */
/*   reserved_chars                                                          */
/*     Bytes reserved for future developments                                */
/*                                                                           */
/*   vector                                                                  */
/*     Optional and variable length data                                     */
/*                                                                           */
/*****************************************************************************/
typedef struct queue_entry
{
  DC_QUEUE_STATUS   q_status;
  NG_WORK_SPACE     ng_space;
  REQUEST_ID        req_id;
  DC_CHAR           subreq_id[DVA_REQID_LEN];
  SCHEDULE_INFO     sched_info;
  DC_ULONG          seq_no;
  DC_ULONG          request_no;
  SCHED_TIME        exec_time;
  DC_USHORT         status;
  DC_USHORT         rsstatus;
  DC_USHORT         unsolicited;
  DC_USHORT         local_origin;
  DC_USHORT         category;
  DC_USHORT         type;
  DC_ULONG          flags;
  DC_CHAR           originator[DVA_TRGNAME_LEN];
  DC_CHAR           destination[DVA_TRGNAME_LEN];
  DC_CHAR           final_dest[DVA_TRGNAME_LEN];
  DC_CHAR           dest_conn[DVA_CONN_NM_LEN];
  DC_NAMES          file;
  DC_USHORT         history_reset;
  DC_CHAR           source[DVA_TRGNAME_LEN];
  DC_CHAR           int_source[DVA_TRGNAME_LEN];
  GENERIC_RR        type_data;
  DC_CHAR           user[DVA_USRNAME_LEN];
  DC_SHORT          hop_count;
  DC_USHORT         original_reqid;
  DC_USHORT         rc_cmd;
  DC_USHORT         disconnected_request;
  DC_USHORT         fprpt_status;
  DC_CHAR           reserved_chars[254];
  DC_CHAR           vector[4];
} QUEUE_ENTRY;

/*****************************************************************************/
/* Values for unsolicited flag                                               */
/*****************************************************************************/
#define  CM_INV_UNSOLICITED   1 /*unsolicited rpt coming from inv req        */
#define  CM_CHKCM_UNSOLICITED 2 /*unsolicited rpt coming from chkcm req      */
#define  CM_MOBC_UNSOLICITED  3 /*unsolicited rpt coming from mob clnt       */

/*****************************************************************************/
/* Values for disconnected_request flag                                      */
/*****************************************************************************/
#define RQ_CONNECTED         0x00  /* command is to be executed connected    */
#define RQ_DISCONNECTED      0x01  /* command is to be executed disconnected */
#define RQ_DISCONN_HELD      0x02  /* (disconn) command to be held till exec */
#define RQ_CLI_GENERATED     0x04  /* (disconn) request generated by client  */

/*****************************************************************************/
/* Values for category field                                                 */
/*****************************************************************************/
#define RQ_COMMAND  1
#define RQ_REQUEST  2
#define RQ_REPORT   3

/*****************************************************************************/
/* Values for status field                                                   */
/*****************************************************************************/
#define ST_WAIT               1
                                   /* request waiting for its scheduled time */
#define ST_START_SCHED        2
                                   /* request has been selected as the to be */
                                   /* processed by the Scheduler             */
#define ST_READY              3
                                   /* Request is ready for processing (has   */
                                   /* been cycled through the Schedule)      */
/* ST_FANNING_OUT retired                                                    */
#define ST_EXPIRED            4
                                   /* Request execution window has expired   */
/* ST_SEC_EFFECTS retired                                                    */
                                   /* Generating Secondary Effects data for  */
                                   /* this report                            */
                                   /* USED ALSO BY RS COMPONENT              */

#define ST_COMPLETED          6    /* STS has successfully completed         */
                                   /* processing the request                 */
/* ST_DONE_CHECKS and ST_CM_DELETE retired                                   */
#define ST_HELD               8
                                   /* request waiting for its scheduled time */
                                   /* and for the target to be released      */
#define ST_STARTED            9
                                   /* Request has been started by STS or     */
                                   /* DACA                                   */
#define ST_CANCEL_PART      100
                                   /* Partial cancel checkpoint              */
                                   /* (only in cancel requests)              */
#define ST_CANCEL_FULL      101
                                   /* Complete cancel checkpoint             */
                                   /* (only in cancel requests)              */
#define ST_PURGED           102
                                   /* Request purged                         */
#define ST_QLIST_BUILT      110
                                   /* Reboot component checkpoint after      */
                                   /* having built all the install reports   */
                                   /* and put them in the FNDSHRBT queue     */
/* #define ST_CM_DELETE          10                                          */
                                   /* Delete CM Status record if             */
                                   /* uninstalling a file                    */


#define RQ_NOT_STARTED        17
                                   /* Initial state of the Request           */
#define RQ_EXPLODING          18
                                   /* During explosion into Data Base        */

#define RQ_WAIT_FOR_SCHED     33
                                   /* Waiting for distribution               */

#define RQ_SCHEDULING         65
                                   /* The status request during the          */
                                   /* distribution to the Scheduler          */
#define RQ_SCHEDULING_AS_REQ  67
                                   /* Special status used in Ordered Queue   */
                                   /* and Ordered List for report being      */
                                   /* processed like a request in            */
                                   /* RQ_SCHEDULING state                    */
#define RQ_SCHEDULED          66
                                   /* The status request after the           */
                                   /* distribution to the Scheduler          */

#define RQ_HELD               129
                                   /* The request is held                    */

#define RQ_DELETED            257
                                   /* The request has been deleted           */
#define RQ_DELETED_BY_SYSTEM  258
                                   /* The request has been deleted by        */
                                   /* the System because its time was        */
                                   /* expired                                */

#define RQ_DELETED_BY_USER    259
                                   /* The request has been deleted by        */
                                   /* the user                               */
#define RQ_DELETED_BY_COND    260
                                   /* The request has been deleted by        */
                                   /* the system because of the              */
                                   /* conditioning                           */

#define RQ_COMPLETED_OK       513
                                   /* The request has been successfully      */
                                   /* completed                              */

#define RQ_COMPLETED_NOK      1025
                                   /* The request has been unsuccessfully    */
                                   /* completed                              */

#define RQ_MAX_STATUSES       1025
                                   /* Number of statuses allowed             */

#define RQ_NO_STATUS        0xffff /* no status                              */

/*****************************************************************************/
/* Values for rsstatus field                                                 */
/*****************************************************************************/
#define RS_NO_STATUS          0

#define RS_SEC_EFFECTS        1
                                   /* This status is used from the RS library*/
                                   /* when the secondary effects where       */
                                   /* already created at the server          */

#define RS_UPDCM_FORCE        2
                                   /* This status is used from the RS library*/
                                   /* to force cm status transitions not     */
                                   /* allowed.                               */

/*****************************************************************************/
/* Values for fprpt_status field                                             */
/*****************************************************************************/
#define RQ_RPT_INITIAL        0

#define RQ_RPT_BUILDING       1

#define RQ_RPT_TRANSFERRING   2

/*****************************************************************************/
/* Possible values for pending_cmd field                                     */
/*****************************************************************************/
/*                                                                           */
/* Fetch pending_cmd values                                                  */
/* ========================                                                  */
/*                                                                           */
/* -  Values RQ_FETCH_SCHEDULED, RQ_STS_FETCH_READY, RQ_STS_FETCH_SCHED and  */
/*    RQ_FETCH_PROCESSED indicate the progress of a send or retrieve.        */
/*    They are used only in RHDB subrequest records, and only with request   */
/*    types Q_FETCH_REQ, Q_STORE_REQ, Q_SINSTALL_REQ and Q_SINITIATE_REQ.    */
/*    (For other request types the use of these values is unnecessary.)      */
/*                                                                           */
/* -  These values are used only when the subrequest record status is        */
/*    RQ_WAIT_FOR_SCHED, RQ_SCHEDULING or RQ_HELD.                           */
/*    (The other subrequest record status values indicate that the request   */
/*    has been scheduled to all targets or is complete, in which case the    */
/*    use of these values is unnecessary or incorrect.)                      */
/*                                                                           */
/* -  These values are linked to the ufid references held by the subrequest  */
/*    record (in req.file.data_ufid and req.file.int_source_ufid).           */
/*      RQ_NO_PENDING_CMD         data_ufid         no reference             */
/*                                int_source_ufid   no reference             */
/*      RQ_FETCH_SCHEDULED        data_ufid         no reference             */
/*                                int_source_ufid   no reference             */
/*      RQ_STS_FETCH_READY        data_ufid         no reference             */
/*                                int_source_ufid   valid reference          */
/*      RQ_STS_FETCH_SCHEDULED    data_ufid         no reference             */
/*                                int_source_ufid   valid reference          */
/*      RQ_FETCH_PROCESSED        data_ufid         valid reference          */
/*                                int_source_ufid   no reference             */
/*    We never have valid references in both data_ufid and int_source_ufid - */
/*    if data_ufid contains a valid reference then int_source_ufid is of no  */
/*    interest, so it is released immediately.                               */
/*                                                                           */
/*****************************************************************************/
#define RQ_NO_PENDING_CMD    1     /* No command is in progress for the      */
                                   /* request and none of the fetch          */
                                   /* values apply                           */
#define RQ_IN_USE            2     /* The request has been completed but     */
                                   /* can not be deleted from the            */
                                   /* database because a new recursion       */
                                   /* must be generated                      */
#define RQ_FETCH_SCHEDULING  3     /* Unused but retained to prevent         */
                                   /* short-term build problems              */
#define RQ_FETCH_SCHEDULED   4     /* A source fetch request has been        */
                                   /* scheduled                              */
#define RQ_STS_FETCH_READY   5     /* Ready to schedule an STS fetch         */
                                   /* request                                */
#define RQ_STS_FETCH_SCHED   6     /* An STS fetch request has been          */
                                   /* scheduled                              */
#define RQ_FETCH_PROCESSED   7     /* A fetch request has been processed     */
#define RQ_DELETE_SCHEDULING 8     /* A Cancel command for the request       */
                                   /* must be distributed to the Sheduler    */
#define RQ_DELETE_SCHEDULED  9     /* A Cancel command for the request       */
                                   /* has been distributed to the Sched.     */
#define RQ_DELETE_PENDING    10    /* A cancel request has to be processed   */


/*****************************************************************************/
/* Values for .flags field                                                   */
/*****************************************************************************/
/*****************************************************************************/
/* RR_SEND, RR_RETRIEVE, RR_SENDF, RR_RETRIEVEF                              */
/* These flags are used to mark a FETCH / STORE                              */
/* request as being part of a UI initiated Send or Retrieve as appropriate   */
/*                                                                           */
/* One of these flags MUST be set on any FETCH request issued through RBH or */
/* it will be rejected.                                                      */
/*                                                                           */
/* RR_STS_FETCH is set in STS fetch requests to distinguish them             */
/* from source fetch requests                                                */
/*                                                                           */
/* RR_TIMED should be set if an 'execute not before' time has been specified */
/* (flag is needed since immediate scheduling would put the current time i   */
/* in the sched_time field and hence cannot be distinguished from a timed    */
/* request specifying that time.  However this distinction is important when */
/* deciding whether to generate an acceptance report for a SNA/MS operation) */
/*                                                                           */
/* RR_REM_REP is set by NGA if this is a report received from a remote target*/
/*                                                                           */
/* RR_RGN_REN_ORG                                                            */
/* is set by NGA when the request originator is in the rgn.ren format.       */
/*                                                                           */
/* RR_RGN_REN_SND                                                            */
/* is set by NGA and RH when the source field is in the rgn.ren format.      */
/*                                                                           */
/* RR_DISCONN_REQ (mobile clients only) is set by DACA if the request is in  */
/* the CDRQ.                                                                 */
/*                                                                           */
/*****************************************************************************/
/*****************************************************************************/
#define RR_SEND           0x00000001
#define RR_RETRIEVE       0x00000002
#define RR_TIMED          0x00000004
#define RR_REM_REP        0x00000010
#define RR_RGN_REN_ORG    0x00000020
#define RR_SENDF          0x00000040
#define RR_RETRIEVEF      0x00000080
#define RR_DELETEF        0x00000100
#define RR_EXECUTEF       0x00000200
#define RR_STS_FETCH      0x00000400
#define RR_RGN_REN_SRC    0x00000800
#define RR_DISCONN_REQ    0x00001000

/*****************************************************************************/
/* The following bitmask may be used to identify 'uncataloged' requests      */
/* - ie, requests which affect specific files, but which identify these      */
/* files using local names, rather than cataloged global names               */
/*****************************************************************************/
#define RR_UNCAT_RQTYPE  (RR_SENDF | RR_RETRIEVEF | RR_DELETEF | RR_EXECUTEF)

/*****************************************************************************/
/* Values for type field                                                     */
/*****************************************************************************/
#define Q_INSTALL_REQ        1     /* install request                        */
#define Q_REMOVE_REQ         2     /* remove request                         */
#define Q_ACCEPT_REQ         3     /* accept request                         */
#define Q_ACTIVATE_REQ       4     /* activate request                       */
#define Q_INITIATE_REQ       5     /* initiate request                       */
#define Q_DELETE_REQ         8     /* delete request                         */
#define Q_STORE_REQ          9     /* Store request                          */
#define Q_FETCH_REQ          10    /* Fetch request                          */
#define Q_SINSTALL_REQ       11    /* Send and Install request               */
#define Q_SINITIATE_REQ      12    /* Send and Initiate request              */
#define Q_UNINSTALL_REQ      13    /* Uninstall request                      */
#define Q_RET_INV_REQ        14    /* Retrieve Inventory request             */
#define Q_CANCEL_REQ         15    /* Cancel request                         */

#define Q_EXECPLAN_REQ       64    /* Exec plan request                      */
#define Q_AUTHORIZE_REQ      65    /* Authorize request                      */
#define Q_UNAUTHORIZE_REQ    66    /* Unauthorize request                    */
#define Q_RESCHEDULE_REQ     67    /* Reschedule request                     */
#define Q_HOLD_REQ           68    /* Hold request                           */
#define Q_RELEASE_REQ        69    /* Release request                        */
#define Q_RESET_REQ          70    /* Reset   request                        */
#define Q_CHKCM_REQ          71    /* Verify CM request                      */
#define Q_AUTOREG_REQ        72    /* Auto registration request              */
#define Q_UPDCM_REQ          73    /* Update CM Status request               */

                                   /* (mobile clients only)                  */
#define Q_OPEN_CONN_WIN_REQ  74    /* Open connection window request         */
#define Q_CLOSE_CONN_WIN_REQ 75    /* Close connection window request        */

#define RQ_NUM_CMDS           8    /* Number of commands allowed by          */
                                   /* the product                            */

#define Q_INSTALL_RPT        17    /* install report                         */
#define Q_REMOVE_RPT         18    /* remove report                          */
#define Q_ACCEPT_RPT         19    /* accept report                          */
#define Q_ACTIVATE_RPT       20    /* activate report                        */
#define Q_INITIATE_RPT       21    /* initiate report                        */
#define Q_TRANSFER_RPT       22    /* send/retrieve report (from SNA/DS)     */
#define Q_DISTRIB_RPT        23    /* distribution report                    */
#define Q_DELETE_RPT         24    /* delete report                          */
#define Q_STORE_RPT          25    /* Store report (to SNA/DS)               */
#define Q_FETCH_RPT          26    /* Fetch report (to SNA/DS)               */
#define Q_SINSTALL_RPT       27    /* Send and Install report                */
#define Q_SINITIATE_RPT      28    /* Send and Initiate report               */
#define Q_UNINSTALL_RPT      29    /* Uninstall report                       */
#define Q_RET_INV_RPT        30    /* Retrieve Inventory report              */
#define Q_REBOOT_COMP        31    /* Reboot Completed report                */
#define Q_VAGUE_CM_RPT       32    /* Report of failed Change                */
                                   /* Management request - request           */
                                   /* type unknown                           */
#define Q_AUTHORIZE_RPT      33    /* Authorize report                       */
#define Q_UNAUTHORIZE_RPT    34    /* Unauthorize report                     */
#define Q_CHKCM_RPT          35    /* chkcm report                           */
#define Q_AUTOREG_RPT        36    /* auto registration report               */
#define Q_UFID_RPT           37    /* ufid use completed report              */
#define Q_UPDCM_RPT          38    /* Updcm  report                          */

                                   /* (mobile clients only)                  */
#define Q_OPEN_CONN_WIN_RPT  39    /* Open connection window report          */
#define Q_CLOSE_CONN_WIN_RPT 40    /* Close connection window report         */
#define Q_OUT_OF_SYNC_RPT    41    /* Client/server out of sync report       */

#define Q_BLANK_REQ         254    /* Blank queue entry used to kick         */
                                   /* the scheduler into action              */
                                   /* also used in the transition table  for */
                                   /* updcm in order not to call rs_report   */
                                   /*                                        */
#define Q_BAD_REQ_TYPE      255    /* Report to an unrecognized request      */
                                   /* also used in the transition table  for */
                                   /* updcm in order not to call rs_report   */
                                   /*                                        */


#define V_TOP_VECTOR V_INST_DRV                                     /* $C1A1 */
#endif
